-- -------------------------------------------------------------------------- --
-- CharScanner GearStats Gem Data                                             --
-- -------------------------------------------------------------------------- --
--                                                                            --
-- NOTE:                                                                      --
-- Gems with a special effect like 'Enigmatic Shadowspirit Diamond'           --
-- [4055 / 52300] ('...and Reduces Snare/Root Duration by 10%...') are        --
-- labeled as EFFECT.                                                         --
--                                                                            --
-- -------------------------------------------------------------------------- --
--                                                                            --
-- Thanks: - Xinhuan                                                          --
--            I used the data from WoWEquip-v1.3 as a base, completed,        --
--            rearranged, added, reformated and tested everything.            --
--         - db.mmo-champion.com                                              --
--         - wowhead.com                                                      --
--                                                                            --
-- -------------------------------------------------------------------------- --

local EFFECT       = 0

local STRENGTH     = 1  -- "ITEM_MOD_STRENGTH_SHORT"
local AGILITY      = 2  -- "ITEM_MOD_AGILITY_SHORT"
local STAMINA      = 3  -- "ITEM_MOD_STAMINA_SHORT"
local INTELLECT    = 4  -- "ITEM_MOD_INTELLECT_SHORT"
local SPIRIT       = 5  -- "ITEM_MOD_SPIRIT_SHORT"

local ATTACKPOWER  = 6  -- "ITEM_MOD_ATTACK_POWER_SHORT"
local BLOCK        = 7  -- "ITEM_MOD_BLOCK_RATING_SHORT"
local DODGE        = 8  -- "ITEM_MOD_DODGE_RATING_SHORT"
local PARRY        = 9  -- "ITEM_MOD_PARRY_RATING_SHORT"
local HIT          = 10 -- "ITEM_MOD_HIT_RATING_SHORT"
local CRIT         = 11 -- "ITEM_MOD_CRIT_RATING_SHORT"
local HASTE        = 12 -- "ITEM_MOD_HASTE_RATING_SHORT"
local EXPERTISE    = 13 -- "ITEM_MOD_EXPERTISE_RATING_SHORT"
local MASTERY      = 14 -- "ITEM_MOD_MASTERY_RATING_SHORT"
local SPELLPOWER   = 15 -- "ITEM_MOD_SPELL_POWER_SHORT"

local PENETRATION  = 16 -- "ITEM_MOD_SPELL_PENETRATION_SHORT"
local RESILIENCE   = 17 -- "ITEM_MOD_RESILIENCE_RATING_SHORT"

local ARMOR        = 18 -- "RESISTANCE0_NAME" 
local HOLY_RES     = 19 -- "RESISTANCE1_NAME" - ITEM_MOD_HOLY_RESISTANCE_SHORT?  -> I have not seen this ingame
local FIRE_RES     = 20 -- "RESISTANCE2_NAME" - ITEM_MOD_FIRE_RESISTANCE_SHORT   -> available ingame (via GetItemStats), but there is no global in GlobalStrings.lua
local NATURE_RES   = 21 -- "RESISTANCE3_NAME" - ITEM_MOD_NATURE_RESISTANCE_SHORT -> available ingame (via GetItemStats), but there is no global in GlobalStrings.lua
local FROST_RES    = 22 -- "RESISTANCE4_NAME" - ITEM_MOD_FROST_RESISTANCE_SHORT  -> available ingame (via GetItemStats), but there is no global in GlobalStrings.lua
local SHADOW_RES   = 23 -- "RESISTANCE5_NAME" - ITEM_MOD_SHADOW_RESISTANCE_SHORT -> available ingame (via GetItemStats), but there is no global in GlobalStrings.lua
local ARCANE_RES   = 24 -- "RESISTANCE6_NAME" - ITEM_MOD_ARCANE_RESISTANCE_SHORT -> available ingame (via GetItemStats), but there is no global in GlobalStrings.lua

local HEALTH       = 25 -- "ITEM_MOD_HEALTH_SHORT"
local MANA         = 26 -- "ITEM_MOD_MANA_SHORT"

local HASTE_RANGED = 27 -- "ITEM_MOD_HASTE_RANGED_RATING_SHORT"
local HIT_RANGED   = 28 -- "ITEM_MOD_HIT_RANGED_RATING_SHORT"
local CRIT_RANGED  = 29 -- "ITEM_MOD_CRIT_RANGED_RATING_SHORT"


local BLUE       = 1
local RED        = 2
local YELLOW     = 3

local BLUEYELLOW = 4 -- GREEN
local REDYELLOW  = 5 -- ORANGE
local REDBLUE    = 6 -- PURPLE
local PRISMATIC  = 7 -- ALL COLORS (expect META, HYDRAULIC, COGWHEEL)

local META       = 8
local HYDRAULIC  = 9
local COGWHEEL   = 10


local gemIDs = {
-- ------------------------------------------------------------------------------------------------------------------ --
-- Cata                                                                                                               --
-- ------------------------------------------------------------------------------------------------------------------ --
-- -------------------------------------------------------------------------- --
-- BLUE                                                                       --
-- -------------------------------------------------------------------------- --
[3897] = {52089, BLUE      , 30, HIT}, -- Rigid Zephyrite
[3894] = {52086, BLUE      , 45, STAMINA}, -- Solid Zephyrite
[3895] = {52087, BLUE      , 30, SPIRIT}, -- Sparkling Zephyrite
[3896] = {52088, BLUE      , 38, PENETRATION}, -- Stormy Zephyrite

[3949] = {52168, BLUE      , 35, HIT}, -- Perfect Rigid Zephyrite
[3952] = {52171, BLUE      , 53, STAMINA}, -- Perfect Solid Zephyrite
[3951] = {52170, BLUE      , 35, SPIRIT}, -- Perfect Sparkling Zephyrite
[3950] = {52169, BLUE      , 44, PENETRATION}, -- Perfect Stormy Zephyrite

[4004] = {52235, BLUE      , 40, HIT}, -- Rigid Ocean Sapphire
[4005] = {52242, BLUE      , 60, STAMINA}, -- Solid Ocean Sapphire
[4006] = {52244, BLUE      , 40, SPIRIT}, -- Sparkling Ocean Sapphire
[4007] = {52246, BLUE      , 50, PENETRATION}, -- Stormy Ocean Sapphire

-- - Jewelcrafters Only
[4039] = {52264, BLUE      , 67, HIT}, -- Rigid Chimera's Eye
[4041] = {52261, BLUE      , 101, STAMINA}, -- Solid Chimera's Eye
[4042] = {52262, BLUE      , 67, SPIRIT}, -- Sparkling Chimera's Eye
[4043] = {52263, BLUE      , 84, PENETRATION}, -- Stormy Chimera's Eye
-- -------------------------------------------------------------------------- --
-- RED                                                                        --
-- -------------------------------------------------------------------------- --
[3889] = {52081, RED       , 30, STRENGTH}, -- Bold Carnelian
[3892] = {52084, RED       , 30, INTELLECT}, -- Brilliant Carnelian
[3890] = {52082, RED       , 30, AGILITY}, -- Delicate Carnelian
[3891] = {52083, RED       , 30, PARRY}, -- Flashing Carnelian
[3893] = {52085, RED       , 30, EXPERTISE}, -- Precise Carnelian

[3957] = {52176, RED       , 35, STRENGTH}, -- Perfect Bold Carnelian
[3954] = {52173, RED       , 35, INTELLECT}, -- Perfect Brilliant Carnelian
[3956] = {52175, RED       , 35, AGILITY}, -- Perfect Delicate Carnelian
[3955] = {52174, RED       , 35, PARRY}, -- Perfect Flashing Carnelian
[3953] = {52172, RED       , 35, EXPERTISE}, -- Perfect Precise Carnelian

[3994] = {52206, RED       , 40, STRENGTH}, -- Bold Inferno Ruby
[3995] = {52207, RED       , 40, INTELLECT}, -- Brilliant Inferno Ruby
[3996] = {52212, RED       , 40, AGILITY}, -- Delicate Inferno Ruby
[3997] = {52216, RED       , 40, PARRY}, -- Flashing Inferno Ruby
[3998] = {52230, RED       , 40, EXPERTISE}, -- Precise Inferno Ruby

-- Jewelcrafters Only
[4031] = {52255, RED       , 67, STRENGTH}, -- Bold Chimera's Eye
[4032] = {52257, RED       , 67, INTELLECT}, -- Brilliant Chimera's Eye
[4033] = {52258, RED       , 67, AGILITY}, -- Delicate Chimera's Eye
[4034] = {52259, RED       , 67, PARRY}, -- Flashing Chimera's Eye
[4037] = {52260, RED       , 67, EXPERTISE}, -- Precise Chimera's Eye
-- -------------------------------------------------------------------------- --
-- YELLOW                                                                     --
-- -------------------------------------------------------------------------- --
[3901] = {52094, YELLOW    , 30, MASTERY}, -- Fractured Alicite
[3899] = {52092, YELLOW    , 30, RESILIENCE}, -- Mystic Alicite
[3900] = {52093, YELLOW    , 30, HASTE}, -- Quick Alicite
[3936] = {52091, YELLOW    , 30, CRIT}, -- Smooth Alicite
[3898] = {52090, YELLOW    , 30, DODGE}, -- Subtle Alicite

[3944] = {52163, YELLOW    , 35, MASTERY}, -- Perfect Fractured Alicite
[3946] = {52165, YELLOW    , 35, RESILIENCE}, -- Perfect Mystic Alicite
[3945] = {52164, YELLOW    , 35, HASTE}, -- Perfect Quick Alicite
[3947] = {52166, YELLOW    , 35, CRIT}, -- Perfect Smooth Alicite
[3948] = {52167, YELLOW    , 35, DODGE}, -- Perfect Subtle Alicite

[3999] = {52219, YELLOW    , 40, MASTERY}, -- Fractured Amberjewel
[4000] = {52226, YELLOW    , 40, RESILIENCE}, -- Mystic Amberjewel
[4001] = {52232, YELLOW    , 40, HASTE}, -- Quick Amberjewel
[4002] = {52241, YELLOW    , 40, CRIT}, -- Smooth Amberjewel
[4003] = {52247, YELLOW    , 40, DODGE}, -- Subtle Amberjewel

-- Jewelcrafters Only
[4035] = {52269, YELLOW    , 67, MASTERY}, -- Fractured Chimera's Eye
[4036] = {52267, YELLOW    , 67, RESILIENCE}, -- Mystic Chimera's Eye
[4038] = {52268, YELLOW    , 67, HASTE}, -- Quick Chimera's Eye
[4040] = {52266, YELLOW    , 67, CRIT}, -- Smooth Chimera's Eye
[4044] = {52265, YELLOW    , 67, DODGE}, -- Subtle Chimera's Eye
-- -------------------------------------------------------------------------- --
-- BLUEYELLOW (GREEN)                                                         --
-- -------------------------------------------------------------------------- --
[3931] = {52124, BLUEYELLOW, 15, HASTE, 23, STAMINA}, -- Forceful Jasper
[3928] = {52121, BLUEYELLOW, 15, CRIT, 23, STAMINA}, -- Jagged Jasper
[3932] = {52125, BLUEYELLOW, 15, HASTE, 15, HIT}, -- Lightning Jasper
[3927] = {52120, BLUEYELLOW, 15, DODGE, 15, HIT}, -- Nimble Jasper
[3929] = {52122, BLUEYELLOW, 15, CRIT, 15, HIT}, -- Piercing Jasper
[3933] = {52126, BLUEYELLOW, 15, MASTERY, 23, STAMINA}, -- Puissant Jasper
[3926] = {52119, BLUEYELLOW, 15, DODGE, 23, STAMINA}, -- Regal Jasper
[3886] = {52128, BLUEYELLOW, 15, MASTERY, 15, HIT}, -- Sensei's Jasper
[3930] = {52123, BLUEYELLOW, 15, RESILIENCE, 23, STAMINA}, -- Steady Jasper
[3885] = {52127, BLUEYELLOW, 15, MASTERY, 15, SPIRIT}, -- Zen Jasper

[3960] = {52133, BLUEYELLOW, 18, HASTE, 26, STAMINA}, -- Perfect Forceful Jasper
[3963] = {52136, BLUEYELLOW, 18, CRIT, 26, STAMINA}, -- Perfect Jagged Jasper
[3959] = {52132, BLUEYELLOW, 18, HASTE, 17, HIT}, -- Perfect Lightning Jasper
[3964] = {52137, BLUEYELLOW, 18, DODGE, 17, HIT}, -- Perfect Nimble Jasper
[3962] = {52135, BLUEYELLOW, 18, CRIT, 17, HIT}, -- Perfect Piercing Jasper
[3958] = {52131, BLUEYELLOW, 18, MASTERY, 26, STAMINA}, -- Perfect Puissant Jasper
[3965] = {52138, BLUEYELLOW, 18, DODGE, 26, STAMINA}, -- Perfect Regal Jasper
[3888] = {52129, BLUEYELLOW, 18, MASTERY, 17, HIT}, -- Perfect Sensei's Jasper
[3961] = {52134, BLUEYELLOW, 18, RESILIENCE, 26, STAMINA}, -- Perfect Steady Jasper
[3887] = {52130, BLUEYELLOW, 18, MASTERY, 17, SPIRIT}, -- Perfect Zen Jasper

[4021] = {52218, BLUEYELLOW, 20, HASTE, 30, STAMINA}, -- Forceful Dream Emerald
[4022] = {52223, BLUEYELLOW, 20, CRIT, 30, STAMINA}, -- Jagged Dream Emerald
[4023] = {52225, BLUEYELLOW, 20, HASTE, 20, HIT}, -- Lightning Dream Emerald
[4024] = {52227, BLUEYELLOW, 20, DODGE, 20, HIT}, -- Nimble Dream Emerald
[4025] = {52228, BLUEYELLOW, 20, CRIT, 20, HIT}, -- Piercing Dream Emerald
[4026] = {52231, BLUEYELLOW, 20, MASTERY, 30, STAMINA}, -- Puissant Dream Emerald
[4027] = {52233, BLUEYELLOW, 20, DODGE, 30, STAMINA}, -- Regal Dream Emerald
[4028] = {52237, BLUEYELLOW, 20, MASTERY, 20, HIT}, -- Sensei's Dream Emerald
[4029] = {52245, BLUEYELLOW, 20, RESILIENCE, 30, STAMINA}, -- Steady Dream Emerald
[4244] = {68741, BLUEYELLOW, 20, RESILIENCE, 20, PENETRATION}, -- Vivid Dream Emerald
[4030] = {52250, BLUEYELLOW, 20, MASTERY, 20, SPIRIT}, -- Zen Dream Emerald
-- -------------------------------------------------------------------------- --
-- REDYELLOW  (ORANGE)                                                        --
-- -------------------------------------------------------------------------- --
[3922] = {52115, REDYELLOW , 15, AGILITY, 15, MASTERY}, -- Adept Hessonite
[3924] = {52117, REDYELLOW , 15, INTELLECT, 15, MASTERY}, -- Artful Hessonite
[3916] = {52109, REDYELLOW , 15, AGILITY, 15, CRIT}, -- Deadly Hessonite
[3919] = {52112, REDYELLOW , 15, AGILITY, 15, HASTE}, -- Deft Hessonite
[3918] = {52111, REDYELLOW , 15, STRENGTH, 15, HASTE}, -- Fierce Hessonite
[3923] = {52116, REDYELLOW , 15, PARRY, 15, MASTERY}, -- Fine Hessonite
[3915] = {52108, REDYELLOW , 15, STRENGTH, 15, CRIT}, -- Inscribed Hessonite
[3925] = {52118, REDYELLOW , 15, EXPERTISE, 15, MASTERY}, -- Keen Hessonite
[3913] = {52106, REDYELLOW , 15, AGILITY, 15, DODGE}, -- Polished Hessonite
[3917] = {52110, REDYELLOW , 15, INTELLECT, 15, CRIT}, -- Potent Hessonite
[3920] = {52113, REDYELLOW , 15, INTELLECT, 15, HASTE}, -- Reckless Hessonite
[3914] = {52107, REDYELLOW , 15, EXPERTISE, 15, DODGE}, -- Resolute Hessonite
[3921] = {52114, REDYELLOW , 15, STRENGTH, 15, MASTERY}, -- Skillful Hessonite

[3969] = {52142, REDYELLOW , 18, AGILITY, 17, MASTERY}, -- Perfect Adept Hessonite
[3967] = {52140, REDYELLOW , 18, INTELLECT, 17, MASTERY}, -- Perfect Artful Hessonite
[3975] = {52148, REDYELLOW , 18, AGILITY, 17, CRIT}, -- Perfect Deadly Hessonite
[3972] = {52145, REDYELLOW , 18, AGILITY, 17, HASTE}, -- Perfect Deft Hessonite
[3973] = {52146, REDYELLOW , 18, STRENGTH, 17, HASTE}, -- Perfect Fierce Hessonite
[3968] = {52141, REDYELLOW , 18, PARRY, 17, MASTERY}, -- Perfect Fine Hessonite
[3976] = {52149, REDYELLOW , 18, STRENGTH, 17, CRIT}, -- Perfect Inscribed Hessonite
[3966] = {52139, REDYELLOW , 18, EXPERTISE, 17, MASTERY}, -- Perfect Keen Hessonite
[3978] = {52151, REDYELLOW , 18, AGILITY, 17, DODGE}, -- Perfect Polished Hessonite
[3974] = {52147, REDYELLOW , 18, INTELLECT, 17, CRIT}, -- Perfect Potent Hessonite
[3971] = {52144, REDYELLOW , 18, INTELLECT, 17, HASTE}, -- Perfect Reckless Hessonite
[3977] = {52150, REDYELLOW , 18, EXPERTISE, 17, DODGE}, -- Perfect Resolute Hessonite
[3970] = {52143, REDYELLOW , 18, STRENGTH, 17, MASTERY}, -- Perfect Skillful Hessonite

[4008] = {52204, REDYELLOW , 20, AGILITY, 20, MASTERY}, -- Adept Ember Topaz
[4009] = {52205, REDYELLOW , 20, INTELLECT, 20, MASTERY}, -- Artful Ember Topaz
[4011] = {52209, REDYELLOW , 20, AGILITY, 20, CRIT}, -- Deadly Ember Topaz
[4012] = {52211, REDYELLOW , 20, AGILITY, 20, HASTE}, -- Deft Ember Topaz
[4013] = {52214, REDYELLOW , 20, STRENGTH, 20, HASTE}, -- Fierce Ember Topaz
[4014] = {52215, REDYELLOW , 20, PARRY, 20, MASTERY}, -- Fine Ember Topaz
[4015] = {52222, REDYELLOW , 20, STRENGTH, 20, CRIT}, -- Inscribed Ember Topaz
[4016] = {52224, REDYELLOW , 20, EXPERTISE, 20, MASTERY}, -- Keen Ember Topaz
[4017] = {52229, REDYELLOW , 20, AGILITY, 20, DODGE}, -- Polished Ember Topaz
[4018] = {52239, REDYELLOW , 20, INTELLECT, 20, CRIT}, -- Potent Ember Topaz
[4010] = {52208, REDYELLOW , 20, INTELLECT, 20, HASTE}, -- Reckless Ember Topaz
[4020] = {52249, REDYELLOW , 20, EXPERTISE, 20, DODGE}, -- Resolute Ember Topaz
[4019] = {52240, REDYELLOW , 20, STRENGTH, 20, MASTERY}, -- Skillful Ember Topaz

[4237] = {68357, REDYELLOW , 20, AGILITY, 20, RESILIENCE}, -- Lucent Ember Topaz
[4238] = {68358, REDYELLOW , 20, STRENGTH, 20, RESILIENCE}, -- Resplendent Ember Topaz
[4236] = {68356, REDYELLOW , 20, INTELLECT, 20, RESILIENCE}, -- Willful Ember Topaz
-- -------------------------------------------------------------------------- --
-- REDBLUE (PURPLE)                                                           --
-- -------------------------------------------------------------------------- --
[3912] = {52105, REDBLUE   , 15, EXPERTISE, 15, HIT}, -- Accurate Nightstone
[3903] = {52097, REDBLUE   , 15, PARRY, 23, STAMINA}, -- Defender's Nightstone
[3908] = {52101, REDBLUE   , 15, STRENGTH, 15, HIT}, -- Etched Nightstone
[3909] = {52102, REDBLUE   , 15, AGILITY, 15, HIT}, -- Glinting Nightstone
[3906] = {52099, REDBLUE   , 15, EXPERTISE, 23, STAMINA}, -- Guardian's Nightstone
[3907] = {52100, REDBLUE   , 15, INTELLECT, 15, SPIRIT}, -- Purified Nightstone
[3910] = {52103, REDBLUE   , 15, PARRY, 15, HIT}, -- Retaliating Nightstone
[3904] = {52096, REDBLUE   , 15, AGILITY, 23, STAMINA}, -- Shifting Nightstone
[3902] = {52095, REDBLUE   , 15, STRENGTH, 23, STAMINA}, -- Sovereign Nightstone
[3905] = {52098, REDBLUE   , 15, INTELLECT, 23, STAMINA}, -- Timeless Nightstone
[3911] = {52104, REDBLUE   , 15, INTELLECT, 15, HIT}, -- Veiled Nightstone

[3979] = {52152, REDBLUE   , 18, EXPERTISE, 17, HIT}, -- Perfect Accurate Nightstone
[3941] = {52160, REDBLUE   , 18, PARRY, 26, STAMINA}, -- Perfect Defender's Nightstone
[3937] = {52156, REDBLUE   , 18, STRENGTH, 17, HIT}, -- Perfect Etched Nightstone
[3982] = {52155, REDBLUE   , 18, AGILITY, 17, HIT}, -- Perfect Glinting Nightstone
[3939] = {52158, REDBLUE   , 18, EXPERTISE, 26, STAMINA}, -- Perfect Guardian's Nightstone
[3938] = {52157, REDBLUE   , 18, INTELLECT, 17, SPIRIT}, -- Perfect Purified Nightstone
[3981] = {52154, REDBLUE   , 18, PARRY, 17, HIT}, -- Perfect Retaliating Nightstone
[3942] = {52161, REDBLUE   , 18, AGILITY, 23, STAMINA}, -- Perfect Shifting Nightstone -- ??? 23 or 26 - Tooltip error or intended???
[3943] = {52162, REDBLUE   , 18, STRENGTH, 26, STAMINA}, -- Perfect Sovereign Nightstone
[3940] = {52159, REDBLUE   , 18, INTELLECT, 26, STAMINA}, -- Perfect Timeless Nightstone
[3980] = {52153, REDBLUE   , 18, INTELLECT, 17, HIT}, -- Perfect Veiled Nightstone

[3983] = {52203, REDBLUE   , 20, EXPERTISE, 20, HIT}, -- Accurate Demonseye
[3984] = {52210, REDBLUE   , 20, PARRY, 30, STAMINA}, -- Defender's Demonseye
[3985] = {52213, REDBLUE   , 20, STRENGTH, 20, HIT}, -- Etched Demonseye
[3987] = {52220, REDBLUE   , 20, AGILITY, 20, HIT}, -- Glinting Demonseye
[3988] = {52221, REDBLUE   , 20, EXPERTISE, 30, STAMINA}, -- Guardian's Demonseye
[3990] = {52236, REDBLUE   , 20, INTELLECT, 20, SPIRIT}, -- Purified Demonseye
[3989] = {52234, REDBLUE   , 20, PARRY, 20, HIT}, -- Retaliating Demonseye
[3991] = {52238, REDBLUE   , 20, AGILITY, 30, STAMINA}, -- Shifting Demonseye
[3992] = {52243, REDBLUE   , 20, STRENGTH, 30, STAMINA}, -- Sovereign Demonseye
[3993] = {52248, REDBLUE   , 20, INTELLECT, 30, STAMINA}, -- Timeless Demonseye
[3986] = {52217, REDBLUE   , 20, INTELLECT, 20, HIT}, -- Veiled Demonseye
-- -------------------------------------------------------------------------- --
-- COGWHEEL                                                                   --
-- -------------------------------------------------------------------------- --
-- Vendor
[4171] = {59491, COGWHEEL  , 208, PARRY}, -- Flashing Cogwheel
[4169] = {59480, COGWHEEL  , 208, MASTERY}, -- Fractured Cogwheel
[4239] = {68660, COGWHEEL  , 208, RESILIENCE}, -- Mystic Cogwheel
[4170] = {59489, COGWHEEL  , 208, EXPERTISE}, -- Precise Cogwheel
[4168] = {59479, COGWHEEL  , 208, HASTE}, -- Quick Cogwheel
[4172] = {59493, COGWHEEL  , 208, HIT}, -- Rigid Cogwheel
[4167] = {59478, COGWHEEL  , 208, CRIT}, -- Smooth Cogwheel
[4173] = {59496, COGWHEEL  , 208, SPIRIT}, -- Sparkling Cogwheel
[4166] = {59477, COGWHEEL  , 208, DODGE}, -- Subtle Cogwheel
-- -------------------------------------------------------------------------- --
-- META                                                                       --
-- -------------------------------------------------------------------------- --
[4251] = {68778, META      , "3R"   , 54, AGILITY, -44797, EFFECT}, -- Agile Shadowspirit Diamond   ---REQ: 3 RED
[4049] = {52294, META      , "2Y"   , 81, STAMINA, -55344, EFFECT}, -- Austere Shadowspirit Diamond   ---REQ: 2 YELLOW
[4047] = {52292, META      , "1B:1Y", 54, INTELLECT, -32842, EFFECT}, -- Bracing Shadowspirit Diamond   ---REQ: 1 BLUE, 1 YELLOW
[4253] = {68780, META      , "3R"   , 54, INTELLECT, -44797, EFFECT}, -- Burning Shadowspirit Diamond   ---REQ: 3 RED
[4046] = {52291, META      , "3R"   , 54, CRIT, -44797, EFFECT}, -- Chaotic Shadowspirit Diamond   ---REQ: 3 RED
[4053] = {52298, META      , "2R"   , 54, CRIT, -11818, EFFECT}, -- Destructive Shadowspirit Diamond   ---REQ: 2 RED
[4050] = {52295, META      , "1R:1Y", 81, STAMINA, -55345, EFFECT}, -- Effulgent Shadowspirit Diamond   ---REQ: 1 RED, 1 YELLOW
[4051] = {52296, META      , "2Y"   , 54, INTELLECT, -46600, EFFECT}, -- Ember Shadowspirit Diamond   ---REQ: 2 YELLOW
[4055] = {52300, META      , "1B:1Y", 54, CRIT, -55378, EFFECT}, -- Enigmatic Shadowspirit Diamond   ---REQ: 1 BLUE, 1 YELLOW
[4048] = {52293, META      , "3B"   , 81, STAMINA, -55283, EFFECT}, -- Eternal Shadowspirit Diamond   ---REQ: 3 BLUE
[4045] = {52289, META      , "2Y"   , 54, MASTERY, -23990, EFFECT}, -- Fleet Shadowspirit Diamond   ---REQ: 2 YELLOW
[4057] = {52302, META      , "1B:1R", 54, INTELLECT, -55366, EFFECT}, -- Forlorn Shadowspirit Diamond   ---REQ: 1 BLUE, 1 RED
[4056] = {52301, META      , "1B:1Y", 54, CRIT, -55357, EFFECT}, -- Impassive Shadowspirit Diamond   ---REQ: 1 BLUE, 1 YELLOW
[4054] = {52299, META      , "2B"   , 81, STAMINA, -55358, EFFECT}, -- Powerful Shadowspirit Diamond   ---REQ: 2 BLUE
[4252] = {68779, META      , "3R"   , 54, STRENGTH, -44797, EFFECT}, -- Reverberating Shadowspirit Diamond   ---REQ: 3 RED
[4052] = {52297, META      , "1B:1Y", 54, SPIRIT, -55256, EFFECT}, -- Revitalizing Shadowspirit Diamond   ---REQ: 1 BLUE, 1 YELLOW
-- ------------------------------------------------------------------------------------------------------------------ --
-- Wrath                                                                                                              --
-- ------------------------------------------------------------------------------------------------------------------ --
-- -------------------------------------------------------------------------- --
-- BLUE                                                                       --
-- -------------------------------------------------------------------------- --
[3383] = {39915, BLUE      , 12, HIT}, -- Rigid Chalcedony
[3387] = {39919, BLUE      , 18, STAMINA}, -- Solid Chalcedony
[3388] = {39920, BLUE      , 12, SPIRIT}, -- Sparkling Chalcedony -- multiID
[3389] = {39927, BLUE      , 12, SPIRIT}, -- Sparkling Chalcedony -- multiID
[3390] = {39932, BLUE      , 15, PENETRATION}, -- Stormy Chalcedony

[3660] = {41447, BLUE      , 14, HIT}, -- Perfect Rigid Chalcedony
[3655] = {41441, BLUE      , 21, STAMINA}, -- Perfect Solid Chalcedony
[3654] = {41440, BLUE      , 14, SPIRIT}, -- Perfect Sparkling Chalcedony -- multiID
[3653] = {41442, BLUE      , 14, SPIRIT}, -- Perfect Sparkling Chalcedony -- multiID
[3656] = {41443, BLUE      , 18, PENETRATION}, -- Perfect Stormy Chalcedony

[3460] = {40014, BLUE      , 16, HIT}, -- Rigid Sky Sapphire
[3454] = {40008, BLUE      , 24, STAMINA}, -- Solid Sky Sapphire
[3455] = {40009, BLUE      , 16, SPIRIT}, -- Sparkling Sky Sapphire -- multiID
[3456] = {40010, BLUE      , 16, SPIRIT}, -- Sparkling Sky Sapphire -- multiID
[3457] = {40011, BLUE      , 20, PENETRATION}, -- Stormy Sky Sapphire

[3528] = {40125, BLUE      , 20, HIT}, -- Rigid Majestic Zircon
[3532] = {40119, BLUE      , 30, STAMINA}, -- Solid Majestic Zircon
[3533] = {40120, BLUE      , 20, SPIRIT}, -- Sparkling Majestic Zircon -- multiID
[3534] = {40121, BLUE      , 20, SPIRIT}, -- Sparkling Majestic Zircon -- multiID
[3535] = {40122, BLUE      , 25, PENETRATION}, -- Stormy Majestic Zircon

[3867] = {45987, BLUE      , 20, HIT}, -- Rigid Stormjewel
[3863] = {45880, BLUE      , 30, STAMINA}, -- Solid Stormjewel
[3864] = {45881, BLUE      , 20, SPIRIT}, -- Sparkling Stormjewel

-- - Jewelcrafters Only
[3742] = {42156, BLUE      , 34, HIT}, -- Rigid Dragon's Eye
[3293] = {36767, BLUE      , 51, STAMINA}, -- Solid Dragon's Eye
[3735] = {42145, BLUE      , 34, SPIRIT}, -- Sparkling Dragon's Eye -- multiID
[3736] = {42146, BLUE      , 34, SPIRIT}, -- Sparkling Dragon's Eye -- multiID
[3747] = {42155, BLUE      , 43, PENETRATION}, -- Stormy Dragon's Eye
-- -------------------------------------------------------------------------- --
-- RED                                                                        --
-- -------------------------------------------------------------------------- --
[3371] = {39900, RED       , 12, STRENGTH}, -- Bold Bloodstone
[3380] = {39911, RED       , 12, INTELLECT}, -- Brilliant Bloodstone -- multiID
[3381] = {39912, RED       , 12, INTELLECT}, -- Brilliant Bloodstone -- multiID
[3374] = {39905, RED       , 12, AGILITY}, -- Delicate Bloodstone -- multiID
[3375] = {39906, RED       , 12, AGILITY}, -- Delicate Bloodstone -- multiID
[3377] = {39908, RED       , 12, PARRY}, -- Flashing Bloodstone
[3379] = {39910, RED       , 12, EXPERTISE}, -- Precise Bloodstone

[3649] = {41432, RED       , 14, STRENGTH}, -- Perfect Bold Bloodstone
[3650] = {41438, RED       , 14, INTELLECT}, -- Perfect Brilliant Bloodstone -- multiID
[3661] = {41444, RED       , 14, INTELLECT}, -- Perfect Brilliant Bloodstone -- multiID
[3651] = {41433, RED       , 14, AGILITY}, -- Perfect Delicate Bloodstone -- multiID
[3644] = {41434, RED       , 14, AGILITY}, -- Perfect Delicate Bloodstone -- multiID
[3648] = {41435, RED       , 14, PARRY}, -- Perfect Flashing Bloodstone
[3647] = {41437, RED       , 14, EXPERTISE}, -- Perfect Precise Bloodstone

[3446] = {39996, RED       , 16, STRENGTH}, -- Bold Scarlet Ruby
[3448] = {39998, RED       , 16, INTELLECT}, -- Brilliant Scarlet Ruby -- multiID
[3458] = {40012, RED       , 16, INTELLECT}, -- Brilliant Scarlet Ruby -- multiID
[3447] = {39997, RED       , 16, AGILITY}, -- Delicate Scarlet Ruby -- multiID
[3449] = {39999, RED       , 16, AGILITY}, -- Delicate Scarlet Ruby -- multiID
[3451] = {40001, RED       , 16, PARRY}, -- Flashing Scarlet Ruby
[3453] = {40003, RED       , 16, EXPERTISE}, -- Precise Scarlet Ruby

[3518] = {40111, RED       , 20, STRENGTH}, -- Bold Cardinal Ruby
[3520] = {40113, RED       , 20, INTELLECT}, -- Brilliant Cardinal Ruby -- multiID
[3526] = {40123, RED       , 20, INTELLECT}, -- Brilliant Cardinal Ruby -- multiID
[3519] = {40112, RED       , 20, AGILITY}, -- Delicate Cardinal Ruby -- multiID
[3521] = {40114, RED       , 20, AGILITY}, -- Delicate Cardinal Ruby -- multiID
[3523] = {40116, RED       , 20, PARRY}, -- Flashing Cardinal Ruby
[3524] = {40118, RED       , 20, EXPERTISE}, -- Precise Cardinal Ruby

[3861] = {45862, RED       , 20, STRENGTH}, -- Bold Stormjewel
[3865] = {45882, RED       , 20, INTELLECT}, -- Brilliant Stormjewel -- multiID
[3866] = {45883, RED       , 20, INTELLECT}, -- Brilliant Stormjewel -- multiID
[3862] = {45879, RED       , 20, AGILITY}, -- Delicate Stormjewel

-- Jewelcrafters Only
[3732] = {42142, RED       , 34, STRENGTH}, -- Bold Dragon's Eye
[3734] = {42144, RED       , 34, INTELLECT}, -- Brilliant Dragon's Eye -- multiID
[3737] = {42148, RED       , 34, INTELLECT}, -- Brilliant Dragon's Eye -- multiID
[3292] = {36766, RED       , 34, AGILITY}, -- Delicate Dragon's Eye -- multiID
[3733] = {42143, RED       , 34, AGILITY}, -- Delicate Dragon's Eye -- multiID
[3741] = {42152, RED       , 34, PARRY}, -- Flashing Dragon's Eye
[3746] = {42154, RED       , 34, EXPERTISE}, -- Precise Dragon's Eye
-- -------------------------------------------------------------------------- --
-- YELLOW                                                                     --
-- -------------------------------------------------------------------------- --
[3385] = {39917, YELLOW    , 12, RESILIENCE}, -- Mystic Sun Crystal
[3386] = {39918, YELLOW    , 12, HASTE}, -- Quick Sun Crystal
[3378] = {39909, YELLOW    , 12, CRIT}, -- Smooth Sun Crystal -- multiID
[3382] = {39914, YELLOW    , 12, CRIT}, -- Smooth Sun Crystal -- multiID
[3376] = {39907, YELLOW    , 12, DODGE}, -- Subtle Sun Crystal -- multiID
[3384] = {39916, YELLOW    , 12, DODGE}, -- Subtle Sun Crystal -- multiID

[3662] = {41445, YELLOW    , 14, RESILIENCE}, -- Perfect Mystic Sun Crystal
[3659] = {41446, YELLOW    , 14, HASTE}, -- Perfect Quick Sun Crystal
[3652] = {41436, YELLOW    , 14, CRIT}, -- Perfect Smooth Sun Crystal -- multiID
[3657] = {41448, YELLOW    , 14, CRIT}, -- Perfect Smooth Sun Crystal -- multiID
[3646] = {41439, YELLOW    , 14, DODGE}, -- Perfect Subtle Sun Crystal -- multiID
[3658] = {41449, YELLOW    , 14, DODGE}, -- Perfect Subtle Sun Crystal -- multiID

[3462] = {40016, YELLOW    , 16, RESILIENCE}, -- Mystic Autumn's Glow
[3463] = {40017, YELLOW    , 16, HASTE}, -- Quick Autumn's Glow
[3452] = {40002, YELLOW    , 16, CRIT}, -- Smooth Autumn's Glow -- multiID
[3459] = {40013, YELLOW    , 16, CRIT}, -- Smooth Autumn's Glow -- multiID
[3450] = {40000, YELLOW    , 16, DODGE}, -- Subtle Autumn's Glow -- multiID
[3461] = {40015, YELLOW    , 16, DODGE}, -- Subtle Autumn's Glow -- multiID

[3530] = {40127, YELLOW    , 20, RESILIENCE}, -- Mystic King's Amber
[3531] = {40128, YELLOW    , 20, HASTE}, -- Quick King's Amber
[3527] = {40124, YELLOW    , 20, CRIT}, -- Smooth King's Amber -- multiID
[3525] = {40117, YELLOW    , 20, CRIT}, -- Smooth King's Amber -- multiID
[3522] = {40115, YELLOW    , 20, DODGE}, -- Subtle King's Amber -- multiID
[3529] = {40126, YELLOW    , 20, DODGE}, -- Subtle King's Amber -- multiID

-- Vendor
[3792] = {44066, YELLOW    , 20, RESILIENCE}, -- Kharmaa's Grace

-- Jewelcrafters Only
[3744] = {42158, YELLOW    , 34, RESILIENCE}, -- Mystic Dragon's Eye
[3739] = {42150, YELLOW    , 34, HASTE}, -- Quick Dragon's Eye
[3738] = {42149, YELLOW    , 34, CRIT}, -- Smooth Dragon's Eye -- multiID
[3745] = {42153, YELLOW    , 34, CRIT}, -- Smooth Dragon's Eye -- multiID
[3740] = {42151, YELLOW    , 34, DODGE}, -- Subtle Dragon's Eye -- multiID
[3743] = {42157, YELLOW    , 34, DODGE}, -- Subtle Dragon's Eye -- multiID
-- -------------------------------------------------------------------------- --
-- BLUEYELLOW (GREEN)                                                         --
-- -------------------------------------------------------------------------- --
[3437] = {39983, BLUEYELLOW, 6, HASTE, 6, SPIRIT}, -- Energized Dark Jade -- multiID
[3442] = {39989, BLUEYELLOW, 6, HASTE, 6, SPIRIT}, -- Energized Dark Jade -- multiID
[3432] = {39978, BLUEYELLOW, 6, HASTE, 9, STAMINA}, -- Forceful Dark Jade
[3391] = {39933, BLUEYELLOW, 6, CRIT, 9, STAMINA}, -- Jagged Dark Jade -- multiID
[3428] = {39974, BLUEYELLOW, 6, CRIT, 9, STAMINA}, -- Jagged Dark Jade -- multiID
[3435] = {39981, BLUEYELLOW, 6, HIT, 6, HASTE}, -- Lightning Dark Jade -- multiID
[3440] = {39986, BLUEYELLOW, 6, HIT, 6, HASTE}, -- Lightning Dark Jade -- multiID
[3434] = {39980, BLUEYELLOW, 6, CRIT, 6, SPIRIT}, -- Misty Dark Jade -- multiID
[3439] = {39985, BLUEYELLOW, 6, CRIT, 6, SPIRIT}, -- Misty Dark Jade -- multiID
[3429] = {39975, BLUEYELLOW, 6, HIT, 6, DODGE}, -- Nimble Dark Jade
[3443] = {39990, BLUEYELLOW, 6, CRIT, 8, PENETRATION}, -- Radiant Dark Jade -- multiID
[3444] = {39991, BLUEYELLOW, 6, CRIT, 8, PENETRATION}, -- Radiant Dark Jade -- multiID
[3396] = {39938, BLUEYELLOW, 6, DODGE, 9, STAMINA}, -- Regal Dark Jade -- multiID
[3430] = {39976, BLUEYELLOW, 6, DODGE, 9, STAMINA}, -- Regal Dark Jade -- multiID
[3445] = {39992, BLUEYELLOW, 6, HASTE, 8, PENETRATION}, -- Shattered Dark Jade
[3431] = {39977, BLUEYELLOW, 6, RESILIENCE, 9, STAMINA}, -- Steady Dark Jade
[3436] = {39982, BLUEYELLOW, 6, RESILIENCE, 6, SPIRIT}, -- Turbid Dark Jade -- multiID
[3441] = {39988, BLUEYELLOW, 6, RESILIENCE, 6, SPIRIT}, -- Turbid Dark Jade -- multiID

[3714] = {41465, BLUEYELLOW, 7, HASTE, 7, SPIRIT}, -- Perfect Energized Dark Jade -- multiID
[3701] = {41467, BLUEYELLOW, 7, HASTE, 7, SPIRIT}, -- Perfect Energized Dark Jade -- multiID
[3701] = {41466, BLUEYELLOW, 7, HASTE, 10, STAMINA}, -- Perfect Forceful Dark Jade
[3665] = {41456, BLUEYELLOW, 7, CRIT, 10, STAMINA}, -- Perfect Jagged Dark Jade -- multiID
[3699] = {41468, BLUEYELLOW, 7, CRIT, 10, STAMINA}, -- Perfect Jagged Dark Jade -- multiID
[3712] = {41469, BLUEYELLOW, 7, HIT, 7, HASTE}, -- Perfect Lightning Dark Jade -- multiID
[3703] = {41475, BLUEYELLOW, 7, HIT, 7, HASTE}, -- Perfect Lightning Dark Jade -- multiID
[3698] = {41470, BLUEYELLOW, 7, CRIT, 7, SPIRIT}, -- Perfect Misty Dark Jade -- multiID
[3710] = {41477, BLUEYELLOW, 7, CRIT, 7, SPIRIT}, -- Perfect Misty Dark Jade -- multiID
[3704] = {41481, BLUEYELLOW, 7, HIT, 7, DODGE}, -- Perfect Nimble Dark Jade
[3709] = {41472, BLUEYELLOW, 7, CRIT, 9, PENETRATION}, -- Perfect Radiant Dark Jade -- multiID
[3715] = {41478, BLUEYELLOW, 7, CRIT, 9, PENETRATION}, -- Perfect Radiant Dark Jade -- multiID
[3668] = {41458, BLUEYELLOW, 7, DODGE, 10, STAMINA}, -- Perfect Regal Dark Jade -- multiID
[3700] = {41464, BLUEYELLOW, 7, DODGE, 10, STAMINA}, -- Perfect Regal Dark Jade -- multiID
[3716] = {41474, BLUEYELLOW, 7, HASTE, 9, PENETRATION}, -- Perfect Shattered Dark Jade
[3708] = {41476, BLUEYELLOW, 7, RESILIENCE, 10, STAMINA}, -- Perfect Steady Dark Jade
[3713] = {41471, BLUEYELLOW, 7, RESILIENCE, 7, SPIRIT}, -- Perfect Turbid Dark Jade -- multiID
[3707] = {41480, BLUEYELLOW, 7, RESILIENCE, 7, SPIRIT}, -- Perfect Turbid Dark Jade -- multiID

[3509] = {40104, BLUEYELLOW, 8, HASTE, 8, SPIRIT}, -- Energized Forest Emerald -- multiID
[3514] = {40105, BLUEYELLOW, 8, HASTE, 8, SPIRIT}, -- Energized Forest Emerald -- multiID
[3504] = {40091, BLUEYELLOW, 8, HASTE, 12, STAMINA}, -- Forceful Forest Emerald
[3470] = {40033, BLUEYELLOW, 8, CRIT, 12, STAMINA}, -- Jagged Forest Emerald -- multiID
[3500] = {40086, BLUEYELLOW, 8, CRIT, 12, STAMINA}, -- Jagged Forest Emerald -- multiID
[3507] = {40099, BLUEYELLOW, 8, HIT, 8, HASTE}, -- Lightning Forest Emerald -- multiID
[3512] = {40100, BLUEYELLOW, 8, HIT, 8, HASTE}, -- Lightning Forest Emerald -- multiID
[3506] = {40095, BLUEYELLOW, 8, CRIT, 8, SPIRIT}, -- Misty Forest Emerald -- multiID
[3511] = {40096, BLUEYELLOW, 8, CRIT, 8, SPIRIT}, -- Misty Forest Emerald -- multiID
[3501] = {40088, BLUEYELLOW, 8, HIT, 8, DODGE}, -- Nimble Forest Emerald
[3515] = {40098, BLUEYELLOW, 8, CRIT, 10, PENETRATION}, -- Radiant Forest Emerald -- multiID
[3516] = {40101, BLUEYELLOW, 8, CRIT, 10, PENETRATION}, -- Radiant Forest Emerald -- multiID
[3468] = {40031, BLUEYELLOW, 8, DODGE, 12, STAMINA}, -- Regal Forest Emerald -- multiID
[3502] = {40089, BLUEYELLOW, 8, DODGE, 12, STAMINA}, -- Regal Forest Emerald -- multiID
[3517] = {40106, BLUEYELLOW, 8, HASTE, 10, PENETRATION}, -- Shattered Forest Emerald
[3503] = {40090, BLUEYELLOW, 8, RESILIENCE, 12, STAMINA}, -- Steady Forest Emerald
[3508] = {40102, BLUEYELLOW, 8, RESILIENCE, 8, SPIRIT}, -- Turbid Forest Emerald -- multiID
[3513] = {40103, BLUEYELLOW, 8, RESILIENCE, 8, SPIRIT}, -- Turbid Forest Emerald -- multiID

[3582] = {40174, BLUEYELLOW, 10, HASTE, 10, SPIRIT}, -- Energized Eye of Zul -- multiID
[3587] = {40179, BLUEYELLOW, 10, HASTE, 10, SPIRIT}, -- Energized Eye of Zul -- multiID
[3577] = {40169, BLUEYELLOW, 10, HASTE, 15, STAMINA}, -- Forceful Eye of Zul
[3543] = {40140, BLUEYELLOW, 10, CRIT, 15, STAMINA}, -- Jagged Eye of Zul -- multiID
[3573] = {40165, BLUEYELLOW, 10, CRIT, 15, STAMINA}, -- Jagged Eye of Zul -- multiID
[3580] = {40172, BLUEYELLOW, 10, HIT, 10, HASTE}, -- Lightning Eye of Zul -- multiID
[3585] = {40177, BLUEYELLOW, 10, HIT, 10, HASTE}, -- Lightning Eye of Zul -- multiID
[3579] = {40171, BLUEYELLOW, 10, CRIT, 10, SPIRIT}, -- Misty Eye of Zul -- multiID
[3584] = {40176, BLUEYELLOW, 10, CRIT, 10, SPIRIT}, -- Misty Eye of Zul -- multiID
[3574] = {40166, BLUEYELLOW, 10, HIT, 10, DODGE}, -- Nimble Eye of Zul
[3588] = {40180, BLUEYELLOW, 10, CRIT, 13, PENETRATION}, -- Radiant Eye of Zul -- multiID
[3589] = {40181, BLUEYELLOW, 10, CRIT, 13, PENETRATION}, -- Radiant Eye of Zul -- multiID
[3575] = {40167, BLUEYELLOW, 10, DODGE, 15, STAMINA}, -- Regal Eye of Zul -- multiID
[3540] = {40138, BLUEYELLOW, 10, DODGE, 15, STAMINA}, -- Regal Eye of Zul -- multiID
[3590] = {40182, BLUEYELLOW, 10, HASTE, 13, PENETRATION}, -- Shattered Eye of Zul
[3576] = {40168, BLUEYELLOW, 10, RESILIENCE, 15, STAMINA}, -- Steady Eye of Zul
[3581] = {40173, BLUEYELLOW, 10, RESILIENCE, 10, SPIRIT}, -- Turbid Eye of Zul -- multiID
[3586] = {40178, BLUEYELLOW, 10, RESILIENCE, 10, SPIRIT}, -- Turbid Eye of Zul -- multiID
-- -------------------------------------------------------------------------- --
-- REDYELLOW  (ORANGE)                                                        --
-- -------------------------------------------------------------------------- --
[3407] = {39949, REDYELLOW , 6, STRENGTH, 6, DODGE}, -- Champion's Huge Citrine
[3410] = {39952, REDYELLOW , 6, AGILITY, 6, CRIT}, -- Deadly Huge Citrine -- multiID
[3422] = {39960, REDYELLOW , 6, AGILITY, 6, CRIT}, -- Deadly Huge Citrine -- multiID
[3413] = {39955, REDYELLOW , 6, AGILITY, 6, HASTE}, -- Deft Huge Citrine -- multiID
[3426] = {39963, REDYELLOW , 6, AGILITY, 6, HASTE}, -- Deft Huge Citrine -- multiID
[3409] = {39951, REDYELLOW , 6, STRENGTH, 6, HASTE}, -- Fierce Huge Citrine
[3405] = {39947, REDYELLOW , 6, STRENGTH, 6, CRIT}, -- Inscribed Huge Citrine
[3412] = {39954, REDYELLOW , 6, AGILITY, 6, RESILIENCE}, -- Lucent Huge Citrine -- multiID
[3424] = {39962, REDYELLOW , 6, AGILITY, 6, RESILIENCE}, -- Lucent Huge Citrine -- multiID
[3414] = {39956, REDYELLOW , 6, INTELLECT, 6, CRIT}, -- Potent Huge Citrine
[3417] = {39959, REDYELLOW , 6, INTELLECT, 6, HASTE}, -- Reckless Huge Citrine -- multiID
[3404] = {39946, REDYELLOW , 6, INTELLECT, 6, HASTE}, -- Reckless Huge Citrine -- multiID
[3421] = {39967, REDYELLOW , 6, EXPERTISE, 6, DODGE}, -- Resolute Huge Citrine
[3408] = {39950, REDYELLOW , 6, STRENGTH, 6, RESILIENCE}, -- Resplendent Huge Citrine
[3419] = {39965, REDYELLOW , 6, PARRY, 6, DODGE}, -- Stalwart Huge Citrine
[3418] = {39964, REDYELLOW , 6, PARRY, 6, DODGE}, -- Stalwart Huge Citrine
[3416] = {39958, REDYELLOW , 6, INTELLECT, 6, RESILIENCE}, -- Willful Huge Citrine

[3683] = {41483, REDYELLOW , 7, STRENGTH, 7, DODGE}, -- Perfect Champion's Huge Citrine
[3767] = {41429, REDYELLOW , 7, AGILITY, 7, CRIT}, -- Perfect Deadly Huge Citrine -- multiID
[3686] = {41484, REDYELLOW , 7, AGILITY, 7, CRIT}, -- Perfect Deadly Huge Citrine -- multiID
[3677] = {41485, REDYELLOW , 7, AGILITY, 7, HASTE}, -- Perfect Deft Huge Citrine -- multiID
[3678] = {41501, REDYELLOW , 7, AGILITY, 7, HASTE}, -- Perfect Deft Huge Citrine -- multiID
[3685] = {41489, REDYELLOW , 7, STRENGTH, 7, HASTE}, -- Perfect Fierce Huge Citrine
[3681] = {41492, REDYELLOW , 7, STRENGTH, 7, CRIT}, -- Perfect Inscribed Huge Citrine
[3680] = {41487, REDYELLOW , 7, AGILITY, 7, RESILIENCE}, -- Perfect Lucent Huge Citrine -- multiID
[3688] = {41493, REDYELLOW , 7, AGILITY, 7, RESILIENCE}, -- Perfect Lucent Huge Citrine -- multiID
[3690] = {41495, REDYELLOW , 7, INTELLECT, 7, CRIT}, -- Perfect Potent Huge Citrine
[3693] = {41497, REDYELLOW , 7, INTELLECT, 7, HASTE}, -- Perfect Reckless Huge Citrine
[3697] = {41498, REDYELLOW , 7, EXPERTISE, 7, DODGE}, -- Perfect Resolute Huge Citrine
[3684] = {41499, REDYELLOW , 7, STRENGTH, 7, RESILIENCE}, -- Perfect Resplendent Huge Citrine
[3695] = {41490, REDYELLOW , 7, PARRY, 7, DODGE}, -- Perfect Stalwart Huge Citrine -- multiID
[3694] = {41500, REDYELLOW , 7, PARRY, 7, DODGE}, -- Perfect Stalwart Huge Citrine -- multiID
[3692] = {41486, REDYELLOW , 7, INTELLECT, 7, RESILIENCE}, -- Perfect Willful Huge Citrine

[3479] = {40039, REDYELLOW , 8, STRENGTH, 8, DODGE}, -- Champion's Monarch Topaz
[3491] = {40052, REDYELLOW , 8, AGILITY, 8, CRIT}, -- Deadly Monarch Topaz -- multiID
[3482] = {40043, REDYELLOW , 8, AGILITY, 8, CRIT}, -- Deadly Monarch Topaz -- multiID
[3494] = {40055, REDYELLOW , 8, AGILITY, 8, HASTE}, -- Deft Monarch Topaz -- multiID
[3485] = {40046, REDYELLOW , 8, AGILITY, 8, HASTE}, -- Deft Monarch Topaz -- multiID
[3481] = {40041, REDYELLOW , 8, STRENGTH, 8, HASTE}, -- Fierce Monarch Topaz
[3477] = {40037, REDYELLOW , 8, STRENGTH, 8, CRIT}, -- Inscribed Monarch Topaz
[3484] = {40045, REDYELLOW , 8, AGILITY, 8, RESILIENCE}, -- Lucent Monarch Topaz -- multiID
[3493] = {40054, REDYELLOW , 8, AGILITY, 8, RESILIENCE}, -- Lucent Monarch Topaz -- multiID
[3487] = {40048, REDYELLOW , 8, INTELLECT, 8, CRIT}, -- Potent Monarch Topaz
[3490] = {40051, REDYELLOW , 8, INTELLECT, 8, HASTE}, -- Reckless Monarch Topaz -- multiID
[3486] = {40047, REDYELLOW , 8, INTELLECT, 8, HASTE}, -- Reckless Monarch Topaz -- multiID
[3498] = {40059, REDYELLOW , 8, EXPERTISE, 8, DODGE}, -- Resolute Monarch Topaz
[3480] = {40040, REDYELLOW , 8, STRENGTH, 8, RESILIENCE}, -- Resplendent Monarch Topaz
[3496] = {40057, REDYELLOW , 8, PARRY, 8, DODGE}, -- Stalwart Monarch Topaz -- multiID
[3495] = {40056, REDYELLOW , 8, PARRY, 8, DODGE}, -- Stalwart Monarch Topaz -- multiID
[3489] = {40050, REDYELLOW , 8, INTELLECT, 8, RESILIENCE}, -- Willful Monarch Topaz

[3551] = {40144, REDYELLOW , 10, STRENGTH, 10, DODGE}, -- Champion's Ametrine
[3554] = {40147, REDYELLOW , 10, AGILITY, 10, CRIT}, -- Deadly Ametrine -- multiID
[3564] = {40156, REDYELLOW , 10, AGILITY, 10, CRIT}, -- Deadly Ametrine -- multiID
[3557] = {40150, REDYELLOW , 10, AGILITY, 10, HASTE}, -- Deft Ametrine -- multiID
[3567] = {40159, REDYELLOW , 10, AGILITY, 10, HASTE}, -- Deft Ametrine -- multiID
[3553] = {40146, REDYELLOW , 10, STRENGTH, 10, HASTE}, -- Fierce Ametrine
[3549] = {40142, REDYELLOW , 10, STRENGTH, 10, CRIT}, -- Inscribed Ametrine
[3556] = {40149, REDYELLOW , 10, AGILITY, 10, RESILIENCE}, -- Lucent Ametrine -- multiID
[3566] = {40158, REDYELLOW , 10, AGILITY, 10, RESILIENCE}, -- Lucent Ametrine -- multiID
[3559] = {40152, REDYELLOW , 10, INTELLECT, 10, CRIT}, -- Potent Ametrine
[3563] = {40155, REDYELLOW , 10, INTELLECT, 10, HASTE}, -- Reckless Ametrine
[3571] = {40163, REDYELLOW , 10, EXPERTISE, 10, DODGE}, -- Resolute Ametrine
[3552] = {40145, REDYELLOW , 10, STRENGTH, 10, RESILIENCE}, -- Resplendent Ametrine
[3568] = {40160, REDYELLOW , 10, PARRY, 10, DODGE}, -- Stalwart Ametrine -- multiID
[3569] = {40161, REDYELLOW , 10, PARRY, 10, DODGE}, -- Stalwart Ametrine -- multiID
[3561] = {40154, REDYELLOW , 10, INTELLECT, 10, RESILIENCE}, -- Willful Ametrine
-- -------------------------------------------------------------------------- --
-- REDBLUE (PURPLE)                                                           --
-- -------------------------------------------------------------------------- --
[3420] = {39966, REDBLUE   , 6, EXPERTISE, 6, HIT}, -- Accurate Shadow Crystal
[3397] = {39939, REDBLUE   , 6, PARRY, 9, STAMINA}, -- Defender's Shadow Crystal
[3411] = {39948, REDBLUE   , 6, STRENGTH, 6, HIT}, -- Etched Shadow Crystal
[3400] = {39942, REDBLUE   , 6, AGILITY, 6, HIT}, -- Glinting Shadow Crystal -- multiID
[3402] = {39944, REDBLUE   , 6, AGILITY, 6, HIT}, -- Glinting Shadow Crystal -- multiID
[3406] = {39953, REDBLUE   , 6, AGILITY, 6, HIT}, -- Glinting Shadow Crystal -- multiID
[3423] = {39961, REDBLUE   , 6, AGILITY, 6, HIT}, -- Glinting Shadow Crystal -- multiID
[3398] = {39940, REDBLUE   , 6, EXPERTISE, 9, STAMINA}, -- Guardian's Shadow Crystal
[3403] = {39945, REDBLUE   , 6, INTELLECT, 8, PENETRATION}, -- Mysterious Shadow Crystal
[3399] = {39941, REDBLUE   , 6, INTELLECT, 6, SPIRIT}, -- Purified Shadow Crystal -- multiID
[3401] = {39943, REDBLUE   , 6, INTELLECT, 6, SPIRIT}, -- Purified Shadow Crystal -- multiID
[3433] = {39979, REDBLUE   , 6, INTELLECT, 6, SPIRIT}, -- Purified Shadow Crystal -- multiID
[3438] = {39984, REDBLUE   , 6, INTELLECT, 6, SPIRIT}, -- Purified Shadow Crystal -- multiID
[3393] = {39935, REDBLUE   , 6, AGILITY, 9, STAMINA}, -- Shifting Shadow Crystal -- multiID
[3395] = {39937, REDBLUE   , 6, AGILITY, 9, STAMINA}, -- Shifting Shadow Crystal -- multiID
[3392] = {39934, REDBLUE   , 6, STRENGTH, 9, STAMINA}, -- Sovereign Shadow Crystal
[3427] = {39968, REDBLUE   , 6, INTELLECT, 9, STAMINA}, -- Timeless Shadow Crystal -- multiID
[3394] = {39936, REDBLUE   , 6, INTELLECT, 9, STAMINA}, -- Timeless Shadow Crystal -- multiID
[3415] = {39957, REDBLUE   , 6, INTELLECT, 6, HIT}, -- Veiled Shadow Crystal

[3696] = {41482, REDBLUE   , 7, EXPERTISE, 7, HIT}, -- Perfect Accurate Shadow Crystal
[3670] = {41451, REDBLUE   , 7, PARRY, 10, STAMINA}, -- Perfect Defender's Shadow Crystal
[3682] = {41488, REDBLUE   , 7, STRENGTH, 7, HIT}, -- Perfect Etched Shadow Crystal
[3663] = {41454, REDBLUE   , 7, AGILITY, 7, HIT}, -- Perfect Glinting Shadow Crystal -- multiID
[3666] = {41462, REDBLUE   , 7, AGILITY, 7, HIT}, -- Perfect Glinting Shadow Crystal -- multiID
[3687] = {41491, REDBLUE   , 7, AGILITY, 7, HIT}, -- Perfect Glinting Shadow Crystal -- multiID
[3679] = {41496, REDBLUE   , 7, AGILITY, 7, HIT}, -- Perfect Glinting Shadow Crystal -- multiID
[3669] = {41453, REDBLUE   , 7, EXPERTISE, 10, STAMINA}, -- Perfect Guardian's Shadow Crystal
[3674] = {41455, REDBLUE   , 7, INTELLECT, 9, PENETRATION}, -- Perfect Mysterious Shadow Crystal
[3673] = {41457, REDBLUE   , 7, INTELLECT, 7, SPIRIT}, -- Perfect Purified Shadow Crystal -- multiID
[3672] = {41459, REDBLUE   , 7, INTELLECT, 7, SPIRIT}, -- Perfect Purified Shadow Crystal -- multiID
[3711] = {41463, REDBLUE   , 7, INTELLECT, 7, SPIRIT}, -- Perfect Purified Shadow Crystal -- multiID
[3705] = {41473, REDBLUE   , 7, INTELLECT, 7, SPIRIT}, -- Perfect Purified Shadow Crystal -- multiID
[3689] = {41494, REDBLUE   , 7, INTELLECT, 7, SPIRIT}, -- Perfect Purified Shadow Crystal -- multiID
[3664] = {41450, REDBLUE   , 7, AGILITY, 10, STAMINA}, -- Perfect Shifting Shadow Crystal -- multiID
[3667] = {41460, REDBLUE   , 7, AGILITY, 10, STAMINA}, -- Perfect Shifting Shadow Crystal -- multiID
[3671] = {41461, REDBLUE   , 7, STRENGTH, 10, STAMINA}, -- Perfect Sovereign Shadow Crystal
[3675] = {41452, REDBLUE   , 7, INTELLECT, 10, STAMINA}, -- Perfect Timeless Shadow Crystal -- multiID
[3706] = {41479, REDBLUE   , 7, INTELLECT, 10, STAMINA}, -- Perfect Timeless Shadow Crystal -- multiID
[3691] = {41502, REDBLUE   , 7, INTELLECT, 7, HIT}, -- Perfect Veiled Shadow Crystal

[3497] = {40058, REDBLUE   , 8, EXPERTISE, 8, HIT}, -- Accurate Twilight Opal
[3469] = {40032, REDBLUE   , 8, PARRY, 12, STAMINA}, -- Defender's Twilight Opal
[3478] = {40038, REDBLUE   , 8, STRENGTH, 8, HIT}, -- Etched Twilight Opal
[3474] = {40024, REDBLUE   , 8, AGILITY, 8, HIT}, -- Glinting Twilight Opal -- multiID
[3475] = {40030, REDBLUE   , 8, AGILITY, 8, HIT}, -- Glinting Twilight Opal -- multiID
[3483] = {40044, REDBLUE   , 8, AGILITY, 8, HIT}, -- Glinting Twilight Opal -- multiID
[3492] = {40053, REDBLUE   , 8, AGILITY, 8, HIT}, -- Glinting Twilight Opal -- multiID
[3471] = {40034, REDBLUE   , 8, EXPERTISE, 12, STAMINA}, -- Guardian's Twilight Opal
[3476] = {40028, REDBLUE   , 8, INTELLECT, 10, PENETRATION}, -- Mysterious Twilight Opal
[3472] = {40026, REDBLUE   , 8, INTELLECT, 8, SPIRIT}, -- Purified Twilight Opal -- multiID
[3473] = {40027, REDBLUE   , 8, INTELLECT, 8, SPIRIT}, -- Purified Twilight Opal -- multiID
[3505] = {40092, REDBLUE   , 8, INTELLECT, 8, SPIRIT}, -- Purified Twilight Opal -- multiID
[3510] = {40094, REDBLUE   , 8, INTELLECT, 8, SPIRIT}, -- Purified Twilight Opal -- multiID
[3465] = {40023, REDBLUE   , 8, AGILITY, 12, STAMINA}, -- Shifting Twilight Opal -- multiID
[3467] = {40029, REDBLUE   , 8, AGILITY, 12, STAMINA}, -- Shifting Twilight Opal -- multiID
[3464] = {40022, REDBLUE   , 8, STRENGTH, 12, STAMINA}, -- Sovereign Twilight Opal
[3466] = {40025, REDBLUE   , 8, INTELLECT, 12, STAMINA}, -- Timeless Twilight Opal -- multiID
[3499] = {40085, REDBLUE   , 8, INTELLECT, 12, STAMINA}, -- Timeless Twilight Opal -- multiID
[3488] = {40049, REDBLUE   , 8, INTELLECT, 8, HIT}, -- Veiled Twilight Opal

[3570] = {40162, REDBLUE   , 10, EXPERTISE, 10, HIT}, -- Accurate Dreadstone
[3541] = {40139, REDBLUE   , 10, PARRY, 15, STAMINA}, -- Defender's Dreadstone
[3550] = {40143, REDBLUE   , 10, STRENGTH, 10, HIT}, -- Etched Dreadstone
[3544] = {40131, REDBLUE   , 10, AGILITY, 10, HIT}, -- Glinting Dreadstone -- multiID
[3547] = {40137, REDBLUE   , 10, AGILITY, 10, HIT}, -- Glinting Dreadstone -- multiID
[3555] = {40148, REDBLUE   , 10, AGILITY, 10, HIT}, -- Glinting Dreadstone -- multiID
[3565] = {40157, REDBLUE   , 10, AGILITY, 10, HIT}, -- Glinting Dreadstone -- multiID
[3542] = {40141, REDBLUE   , 10, EXPERTISE, 15, STAMINA}, -- Guardian's Dreadstone
[3548] = {40135, REDBLUE   , 10, INTELLECT, 13, PENETRATION}, -- Mysterious Dreadstone
[3545] = {40133, REDBLUE   , 10, INTELLECT, 10, SPIRIT}, -- Purified Dreadstone -- multiID
[3558] = {40151, REDBLUE   , 10, INTELLECT, 10, SPIRIT}, -- Purified Dreadstone -- multiID
[3583] = {40175, REDBLUE   , 10, INTELLECT, 10, SPIRIT}, -- Purified Dreadstone -- multiID
[3546] = {40134, REDBLUE   , 10, INTELLECT, 10, SPIRIT}, -- Purified Dreadstone -- multiID
[3578] = {40170, REDBLUE   , 10, INTELLECT, 10, SPIRIT}, -- Purified Dreadstone -- multiID
[3537] = {40130, REDBLUE   , 10, AGILITY, 15, STAMINA}, -- Shifting Dreadstone -- multiID
[3539] = {40136, REDBLUE   , 10, AGILITY, 15, STAMINA}, -- Shifting Dreadstone -- multiID
[3536] = {40129, REDBLUE   , 10, STRENGTH, 15, STAMINA}, -- Sovereign Dreadstone
[3572] = {40164, REDBLUE   , 10, INTELLECT, 15, STAMINA}, -- Timeless Dreadstone -- multiID
[3538] = {40132, REDBLUE   , 10, INTELLECT, 15, STAMINA}, -- Timeless Dreadstone -- multiID
[3560] = {40153, REDBLUE   , 10, INTELLECT, 10, HIT}, -- Veiled Dreadstone
-- -------------------------------------------------------------------------- --
-- PRISMATIC                                                                  --
-- -------------------------------------------------------------------------- --
[3749] = {42701, PRISMATIC , 4, STRENGTH, 4, AGILITY, 4, STAMINA, 4, INTELLECT, 4, SPIRIT}, -- Enchanted Pearl
[3750] = {42702, PRISMATIC , 6, STRENGTH, 6, AGILITY, 6, STAMINA, 6, INTELLECT, 6, SPIRIT}, -- Enchanted Tear
[3879] = {49110, PRISMATIC , 10, STRENGTH, 10, AGILITY, 10, STAMINA, 10, INTELLECT, 10, SPIRIT}, -- Nightmare Tear
-- -------------------------------------------------------------------------- --
-- META                                                                       --
-- -------------------------------------------------------------------------- --
-- Jewelcrafting
[3637] = {41380, META      , "2B:1R"   , 32, STAMINA, -55344, EFFECT}, -- Austere Earthsiege Diamond   ---REQ: 2 BLUE, 1 RED
[3641] = {41389, META      , "2R:1Y"   , 21, CRIT, -55337, EFFECT}, -- Beaming Earthsiege Diamond   ---REQ: 2 RED, 1 YELLOW
[3626] = {41395, META      , "2R:1B"   , 21, INTELLECT, -32842, EFFECT}, -- Bracing Earthsiege Diamond   ---REQ: 2 RED, 1 BLUE
[3631] = {41396, META      , "2R:1B"   , 21, DODGE, -55283, EFFECT}, -- Eternal Earthsiege Diamond   ---REQ: 2 RED, 1 BLUE
[3627] = {41401, META      , "1R:1B:1Y", 21, INTELLECT, -55381, EFFECT}, -- Insightful Earthsiege Diamond   ---REQ: 1 RED, 1 BLUE, 1 YELLOW
[3640] = {41385, META      , "2B:1R"   , 21, HASTE, -61356, EFFECT}, -- Invigorating Earthsiege Diamond   ---REQ: 2 BLUE, 1 RED
[3638] = {41381, META      , "2Y:1B"   , 21, CRIT, -55358, EFFECT}, -- Persistent Earthsiege Diamond   ---REQ: 2 YELLOW, 1 BLUE
[3642] = {41397, META      , "3B"      , 32, STAMINA, -55358, EFFECT}, -- Powerful Earthsiege Diamond   ---REQ: 3 BLUE
[3628] = {41398, META      , "3R"      , 21, AGILITY, -39957, EFFECT}, -- Relentless Earthsiege Diamond   ---REQ: 3 RED
[3639] = {41382, META      , "1R:1B:1Y", 21, INTELLECT, -55358, EFFECT}, -- Trenchant Earthsiege Diamond   ---REQ: 1 RED, 1 BLUE, 1 YELLOW

[3621] = {41285, META      , "3R"      , 21, CRIT, -44797, EFFECT}, -- Chaotic Skyflare Diamond   ---REQ: 3 RED
[3622] = {41307, META      , "1R:1B:1Y", 25, CRIT, -11818, EFFECT}, -- Destructive Skyflare Diamond   ---REQ: 1 RED, 1 BLUE, 1 YELLOW
[3623] = {41333, META      , "3R"      , 21, INTELLECT, -55275, EFFECT}, -- Ember Skyflare Diamond   ---REQ: 3 RED
[3624] = {41335, META      , "2R:1Y"   , 21, CRIT, -55378, EFFECT}, -- Enigmatic Skyflare Diamond   ---REQ: 2 RED, 1 YELLOW
[3635] = {41378, META      , "2Y:1B"   , 21, INTELLECT, -55366, EFFECT}, -- Forlorn Skyflare Diamond   ---REQ: 2 YELLOW, 1 BLUE
[3636] = {41379, META      , "2R:1B"   , 21, CRIT, -55357, EFFECT}, -- Impassive Skyflare Diamond   ---REQ: 2 RED, 1 BLUE
[3633] = {41376, META      , "2R"      , 21, SPIRIT, -55256, EFFECT}, -- Revitalizing Skyflare Diamond   ---REQ: 2 RED
[3634] = {41377, META      , "2B:1R"   , 32, STAMINA, -55345, EFFECT}, -- Shielded Skyflare Diamond   ---REQ: 2 BLUE, 1 RED
[3625] = {41339, META      , "2Y:1R"   , 21, CRIT, -23990, EFFECT}, -- Swift Skyflare Diamond   ---REQ: 2 YELLOW, 1 RED
[3643] = {41400, META      , "1R:1B:1Y", -55380, EFFECT}, -- Thundering Skyflare Diamond   ---REQ: 1 RED, 1 BLUE, 1 YELLOW
[3632] = {41375, META      , "1R:1B:1Y", 21, INTELLECT, -23990, EFFECT}, -- Tireless Skyflare Diamond   ---REQ: 1 RED, 1 BLUE, 1 YELLOW

-- Wintergrasp
[3801] = {44081, META      , "2R:1B"   , 17, CRIT, -55378, EFFECT}, -- Enigmatic Starflare Diamond   ---REQ: 2 RED, 1 BLUE
[3802] = {44084, META      , "2Y:1B"   , 17, INTELLECT, -55366, EFFECT}, -- Forlorn Starflare Diamond   ---REQ: 2 YELLOW, 1 BLUE
[3800] = {44082, META      , "2B:1R"   , 17, CRIT, -55357, EFFECT}, -- Impassive Starflare Diamond   ---REQ: 2 BLUE, 1 RED
[3798] = {44076, META      , "2Y:1R"   , 17, CRIT, -23990, EFFECT}, -- Swift Starflare Diamond   ---REQ: 2 YELLOW, 1 RED
[3799] = {44078, META      , "1R:1B:1Y", 17, INTELLECT, -23990, EFFECT}, -- Tireless Starflare Diamond   ---REQ: 1 RED, 1 BLUE, 1 YELLOW

[3803] = {44087, META      , "3B"      , 17, CRIT, -55358, EFFECT}, -- Persistent Earthshatter Diamond   ---REQ: 3 BLUE
[3804] = {44088, META      , "2B:1Y"   , 26, STAMINA, -55358, EFFECT}, -- Powerful Earthshatter Diamond   ---REQ: 2 BLUE, 1 YELLOW
[3805] = {44089, META      , "1R:1B:1Y", 17, INTELLECT, -55358, EFFECT}, -- Trenchant Earthshatter Diamond   ---REQ: 1 RED, 1 BLUE, 1 YELLOW
-- ------------------------------------------------------------------------------------------------------------------ --
-- BC                                                                                                                 --
-- ------------------------------------------------------------------------------------------------------------------ --
-- -------------------------------------------------------------------------- --
-- BLUE                                                                       --
-- -------------------------------------------------------------------------- --
[2697] = {23116, BLUE      , 6, HIT}, -- Rigid Azure Moonstone -- multiID
[3104] = {31860, BLUE      , 6, HIT}, -- Rigid Azure Moonstone -- multiID
[2698] = {23118, BLUE      , 9, STAMINA}, -- Solid Azure Moonstone
[2699] = {23119, BLUE      , 6, SPIRIT}, -- Sparkling Azure Moonstone -- multiID
[2701] = {23121, BLUE      , 6, SPIRIT}, -- Sparkling Azure Moonstone -- multiID
[2700] = {23120, BLUE      , 8, PENETRATION}, -- Stormy Azure Moonstone

[2764] = {24051, BLUE      , 8, HIT}, -- Rigid Star of Elune -- multiID
[3105] = {31861, BLUE      , 8, HIT}, -- Rigid Star of Elune -- multiID
[2731] = {24033, BLUE      , 12, STAMINA}, -- Solid Star of Elune
[2732] = {24035, BLUE      , 8, SPIRIT}, -- Sparkling Star of Elune -- multiID
[2733] = {24037, BLUE      , 8, SPIRIT}, -- Sparkling Star of Elune -- multiID
[2765] = {24039, BLUE      , 10, PENETRATION}, -- Stormy Star of Elune

[3128] = {32206, BLUE      , 10, HIT}, -- Rigid Empyrean Sapphire -- multiID
[3132] = {32210, BLUE      , 10, HIT}, -- Rigid Empyrean Sapphire -- multiID
[3122] = {32200, BLUE      , 15, STAMINA}, -- Solid Empyrean Sapphire
[3123] = {32201, BLUE      , 10, SPIRIT}, -- Sparkling Empyrean Sapphire -- multiID
[3124] = {32202, BLUE      , 10, SPIRIT}, -- Sparkling Empyrean Sapphire -- multiID
[3125] = {32203, BLUE      , 13, PENETRATION}, -- Stormy Empyrean Sapphire

-- Quest Rewards
[3262] = {34256, BLUE      , 15, STAMINA}, -- Charmed Amani Jewel (Zul'Aman)
[3268] = {34831, BLUE      , 15, STAMINA}, -- Eye of the Sea (Daily Fishing Shattrath)

-- Vendor
[2966] = {28468, BLUE      , 4, HIT}, -- Rigid Zircon
[2961] = {28463, BLUE      , 6, STAMINA}, -- Solid Zircon
[2962] = {28464, BLUE      , 4, SPIRIT}, -- Sparkling Zircon
[2963] = {28465, BLUE      , 4, SPIRIT}, -- Sparkling Zircon

-- Jewelcrafters Only
[3212] = {33135, BLUE      , 18, STAMINA}, -- Falling Star
-- -------------------------------------------------------------------------- --
-- RED                                                                        --
-- -------------------------------------------------------------------------- --
[2691] = {23095, RED       , 6, STRENGTH}, -- Bold Blood Garnet
[2690] = {23094, RED       , 6, INTELLECT}, -- Brilliant Blood Garnet -- multiID
[2692] = {23096, RED       , 7, INTELLECT}, -- Brilliant Blood Garnet -- multiID
[2694] = {23113, RED       , 6, INTELLECT}, -- Brilliant Blood Garnet -- multiID
[2693] = {23097, RED       , 6, AGILITY}, -- Delicate Blood Garnet -- multiID
[2971] = {28595, RED       , 6, AGILITY}, -- Delicate Blood Garnet -- multiID

[2725] = {24027, RED       , 8, STRENGTH}, -- Bold Living Ruby
[2727] = {24029, RED       , 8, INTELLECT}, -- Brilliant Living Ruby -- multiID
[2728] = {24030, RED       , 8, INTELLECT}, -- Brilliant Living Ruby -- multiID
[2734] = {24047, RED       , 8, INTELLECT}, -- Brilliant Living Ruby -- multiID
[2726] = {24028, RED       , 8, AGILITY}, -- Delicate Living Ruby -- multiID
[2729] = {24031, RED       , 8, AGILITY}, -- Delicate Living Ruby -- multiID
[2754] = {24036, RED       , 8, PARRY}, -- Flashing Living Ruby

[3115] = {32193, RED       , 10, STRENGTH}, -- Bold Crimson Spinel
[3117] = {32195, RED       , 10, INTELLECT}, -- Brilliant Crimson Spinel -- multiID
[3118] = {32196, RED       , 10, INTELLECT}, -- Brilliant Crimson Spinel -- multiID
[3126] = {32204, RED       , 10, INTELLECT}, -- Brilliant Crimson Spinel -- multiID
[3116] = {32194, RED       , 10, AGILITY}, -- Delicate Crimson Spinel -- multiID
[3119] = {32197, RED       , 10, AGILITY}, -- Delicate Crimson Spinel -- multiID
[3121] = {32199, RED       , 10, PARRY}, -- Flashing Crimson Spinel

-- Vendor
[2945] = {28362, RED       , 10, AGILITY}, -- Delicate Ornate Ruby (Stormwind / Orgrimmar)
[2912] = {28118, RED       , 10, INTELLECT}, -- Brilliant Ornate Ruby (Stormwind / Orgrimmar)
[3335] = {38545, RED       , 10, AGILITY}, -- Delicate Ornate Ruby (Tanaris)
[3339] = {38549, RED       , 10, INTELLECT}, -- Brilliant Ornate Ruby (Tanaris)
[3103] = {30598, RED       , 8, STRENGTH}, -- Don Amancio's Heart (A) Nagrand
[3065] = {30571, RED       , 8, STRENGTH}, -- Don Rodrigo's Heart (H) Nagrand
[4212] = {63696, RED       , 7, STRENGTH}, -- Bold Blood Garnet (A) Hellfire Peninsula
[4213] = {63697, RED       , 7, STRENGTH}, -- Bold Blood Garnet (H) Hellfire Peninsula
[2924] = {27812, RED       , 7, INTELLECT}, -- Brilliant Blood Garnet (A) Hellfire Peninsula
[2896] = {27777, RED       , 7, INTELLECT}, -- Brilliant Blood Garnet (H) Hellfire Peninsula
[2944] = {28361, RED       , 7, AGILITY}, -- Delicate Blood Garnet (A) Hellfire Peninsula
[2943] = {28360, RED       , 7, AGILITY}, -- Delicate Blood Garnet (H) Hellfire Peninsula
[2956] = {28458, RED       , 4, STRENGTH}, -- Bold Tourmaline
[2958] = {28460, RED       , 4, INTELLECT}, -- Brilliant Tourmaline -- multiID
[2959] = {28461, RED       , 4, INTELLECT}, -- Brilliant Tourmaline -- multiID
[2964] = {28466, RED       , 4, INTELLECT}, -- Brilliant Tourmaline -- multiID
[2957] = {28459, RED       , 4, AGILITY}, -- Delicate Tourmaline -- multiID
[2960] = {28462, RED       , 4, AGILITY}, -- Delicate Tourmaline -- multiID

-- Quest Rewards
[3281] = {35487, RED       , 10, AGILITY}, -- Delicate Crimson Spinel (Quest: 'Hard to Kill' / Magister's Terrace)
[3282] = {35488, RED       , 10, INTELLECT}, -- Brilliant Crimson Spinel (Quest: 'Hard to Kill' / Magister's Terrace)
[3283] = {35489, RED       , 10, INTELLECT}, -- Brilliant Crimson Spinel

-- Jewelcrafters Only
[3208] = {33131, RED       , 12, AGILITY}, -- Crimson Sun
[3210] = {33133, RED       , 12, INTELLECT}, -- Don Julio's Heart
[3211] = {33134, RED       , 12, INTELLECT}, -- Kailee's Rose
-- -------------------------------------------------------------------------- --
-- YELLOW                                                                     --
-- -------------------------------------------------------------------------- --
[2695] = {23114, YELLOW    , 6, CRIT}, -- Smooth Golden Draenite -- multiID
[2942] = {28290, YELLOW    , 6, CRIT}, -- Smooth Golden Draenite -- multiID
[2696] = {23115, YELLOW    , 6, DODGE}, -- Subtle Golden Draenite

[2759] = {24053, YELLOW    , 8, RESILIENCE}, -- Mystic Dawnstone
[3270] = {35315, YELLOW    , 8, HASTE}, -- Quick Dawnstone
[2735] = {24048, YELLOW    , 8, CRIT}, -- Smooth Dawnstone -- multiID
[2736] = {24050, YELLOW    , 8, CRIT}, -- Smooth Dawnstone -- multiID
[2730] = {24032, YELLOW    , 8, DODGE}, -- Subtle Dawnstone -- multiID
[2737] = {24052, YELLOW    , 8, DODGE}, -- Subtle Dawnstone -- multiID

[3131] = {32209, YELLOW    , 10, RESILIENCE}, -- Mystic Lionseye
[3287] = {35761, YELLOW    , 10, HASTE}, -- Quick Lionseye
[3127] = {32205, YELLOW    , 10, CRIT}, -- Smooth Lionseye -- multiID
[3129] = {32207, YELLOW    , 10, CRIT}, -- Smooth Lionseye -- multiID
[3120] = {32198, YELLOW    , 10, DODGE}, -- Subtle Lionseye -- multiID
[3130] = {32208, YELLOW    , 10, DODGE}, -- Subtle Lionseye -- multiID

-- Vendor
[2913] = {28119, YELLOW    , 10, CRIT}, -- Smooth Ornate Dawnstone (Stormwind / Orgrimmar)
[2914] = {28120, YELLOW    , 10, CRIT}, -- Smooth Ornate Dawnstone (Stormwind / Orgrimmar)
[3340] = {38550, YELLOW    , 10, CRIT}, -- Smooth Ornate Dawnstone (Tanaris)
[3336] = {38546, YELLOW    , 10, CRIT}, -- Smooth Ornate Dawnstone (Tanaris)
[2891] = {27679, YELLOW    , 10, RESILIENCE}, -- Mystic Dawnstone (Nagrand Halaa)
[2965] = {28467, YELLOW    , 4, CRIT}, -- Smooth Amber -- multiID
[2967] = {28469, YELLOW    , 4, CRIT}, -- Smooth Amber -- multiID
[2968] = {28470, YELLOW    , 4, DODGE}, -- Subtle Amber

-- Jewelcrafters Only
[3217] = {33140, YELLOW    , 12, CRIT}, -- Blood of Amber
[3221] = {33144, YELLOW    , 12, DODGE}, -- Facet of Eternity
[3220] = {33143, YELLOW    , 12, CRIT}, -- Stone of Blades
-- -------------------------------------------------------------------------- --
-- BLUEYELLOW (GREEN)                                                         --
-- -------------------------------------------------------------------------- --
[2762] = {23103, BLUEYELLOW, 3, CRIT, 4, PENETRATION}, -- Radiant Deep Peridot
[2757] = {23104, BLUEYELLOW, 3, CRIT, 4, STAMINA}, -- Jagged Deep Peridot
[2706] = {23105, BLUEYELLOW, 3, DODGE, 4, STAMINA}, -- Regal Deep Peridot

[3272] = {35318, BLUEYELLOW, 4, HASTE, 6, STAMINA}, -- Forceful Talasite
[2758] = {24067, BLUEYELLOW, 4, CRIT, 6, STAMINA}, -- Jagged Talasite
[2763] = {24066, BLUEYELLOW, 4, CRIT, 5, PENETRATION}, -- Radiant Talasite
[2743] = {24062, BLUEYELLOW, 4, DODGE, 6, STAMINA}, -- Regal Talasite -- multiID
[3280] = {35707, BLUEYELLOW, 4, DODGE, 6, STAMINA}, -- Regal Talasite -- multiID
[3226] = {33782, BLUEYELLOW, 4, RESILIENCE, 6, STAMINA}, -- Steady Talasite

[3285] = {35759, BLUEYELLOW, 5, HASTE, 7, STAMINA}, -- Forceful Seaspray Emerald
[3148] = {32226, BLUEYELLOW, 5, CRIT, 7, STAMINA}, -- Jagged Seaspray Emerald
[3146] = {32224, BLUEYELLOW, 5, CRIT, 6, PENETRATION}, -- Radiant Seaspray Emerald
[3145] = {32223, BLUEYELLOW, 5, DODGE, 7, STAMINA}, -- Regal Seaspray Emerald
[3284] = {35758, BLUEYELLOW, 5, RESILIENCE, 7, STAMINA}, -- Steady Seaspray Emerald

-- Vendor
[2921] = {27809, BLUEYELLOW, 3, STAMINA, 4, CRIT}, -- Jagged Deep Peridot (A) Hellfire Peninsula
[2899] = {27786, BLUEYELLOW, 3, STAMINA, 4, CRIT}, -- Jagged Deep Peridot (H) Hellfire Peninsula
[2923] = {27820, BLUEYELLOW, 3, STAMINA, 4, CRIT}, -- Jagged Deep Peridot (A)
[2898] = {27785, BLUEYELLOW, 3, STAMINA, 4, CRIT}, -- Jagged Deep Peridot (H)
[3161] = {32639, BLUEYELLOW, 4, STAMINA, 4, CRIT}, -- Jagged Mossjewel (Skyguard Bash'ir Landing Event)

-- Instance Drops
[3047] = {30548, BLUEYELLOW, 5, CRIT, 6, STAMINA}, -- Jagged Chrysoprase -- multiID
[3085] = {30602, BLUEYELLOW, 5, CRIT, 6, STAMINA}, -- Jagged Chrysoprase -- multiID
[3062] = {30565, BLUEYELLOW, 5, CRIT, 6, STAMINA}, -- Jagged Chrysoprase -- multiID
[3089] = {30606, BLUEYELLOW, 5, HIT, 4, HASTE}, -- Lightning Chrysoprase
[3049] = {30550, BLUEYELLOW, 5, CRIT, 4, SPIRIT}, -- Misty Chrysoprase -- multiID
[3058] = {30560, BLUEYELLOW, 5, CRIT, 4, SPIRIT}, -- Misty Chrysoprase -- multiID
[3088] = {30605, BLUEYELLOW, 5, HIT, 4, DODGE}, -- Nimble Chrysoprase -- multiID
[3068] = {30575, BLUEYELLOW, 5, HIT, 4, DODGE}, -- Nimble Chrysoprase -- multiID
[3091] = {30608, BLUEYELLOW, 5, CRIT, 4, PENETRATION}, -- Radiant Chrysoprase
[3078] = {30590, BLUEYELLOW, 6, STAMINA, 5, DODGE}, -- Regal Chrysoprase -- multiID
[3060] = {30563, BLUEYELLOW, 6, STAMINA, 5, DODGE}, -- Regal Chrysoprase -- multiID
[3082] = {30594, BLUEYELLOW, 6, STAMINA, 5, DODGE}, -- Regal Chrysoprase -- multiID
[3084] = {30601, BLUEYELLOW, 5, RESILIENCE, 6, STAMINA}, -- Steady Chrysoprase -- multiID
[3080] = {30592, BLUEYELLOW, 5, RESILIENCE, 6, STAMINA}, -- Steady Chrysoprase -- multiID
-- -------------------------------------------------------------------------- --
-- REDYELLOW  (ORANGE)                                                        --
-- -------------------------------------------------------------------------- --
[3113] = {31869, REDYELLOW , 3, CRIT, 3, AGILITY}, -- Deadly Flame Spessarite
[2752] = {23098, REDYELLOW , 3, CRIT, 3, STRENGTH}, -- Inscribed Flame Spessarite
[2760] = {23101, REDYELLOW , 3, CRIT, 3, INTELLECT}, -- Potent Flame Spessarite
[2705] = {23099, REDYELLOW , 3, HASTE, 3, INTELLECT}, -- Reckless Flame Spessarite

[3112] = {31868, REDYELLOW , 4, CRIT, 4, AGILITY}, -- Deadly Noble Topaz
[2753] = {24058, REDYELLOW , 4, CRIT, 4, STRENGTH}, -- Inscribed Noble Topaz
[2761] = {24059, REDYELLOW , 4, CRIT, 4, INTELLECT}, -- Potent Noble Topaz
[2742] = {24060, REDYELLOW , 4, HASTE, 4, INTELLECT}, -- Reckless Noble Topaz -- multiID
[3271] = {35316, REDYELLOW , 4, HASTE, 4, INTELLECT}, -- Reckless Noble Topaz -- multiID

[3144] = {32222, REDYELLOW , 5, CRIT, 5, AGILITY}, -- Deadly Pyrestone
[3139] = {32217, REDYELLOW , 5, CRIT, 5, STRENGTH}, -- Inscribed Pyrestone
[3140] = {32218, REDYELLOW , 5, CRIT, 5, INTELLECT}, -- Potent Pyrestone
[3141] = {32219, REDYELLOW , 5, HASTE, 5, INTELLECT}, -- Reckless Pyrestone -- multiID
[3286] = {35760, REDYELLOW , 5, HASTE, 5, INTELLECT}, -- Reckless Pyrestone -- multiID

-- Vendor
[2946] = {28363, REDYELLOW , 5, AGILITY, 5, CRIT}, -- Deadly Ornate Topaz (Stormwind / Orgrimmar)
[2916] = {28123, REDYELLOW , 5, CRIT, 5, INTELLECT}, -- Potent Ornate Topaz (Stormwind / Orgrimmar)
[3337] = {38547, REDYELLOW , 5, AGILITY, 5, CRIT}, -- Deadly Ornate Topaz (Tanaris)
[3338] = {38548, REDYELLOW , 5, CRIT, 5, INTELLECT}, -- Potent Ornate Topaz (Tanaris)
[3159] = {32637, REDYELLOW , 5, AGILITY, 4, CRIT}, -- Deadly Citrine (Skyguard Bash'ir Landing Event)
[3160] = {32638, REDYELLOW , 5, INTELLECT, 4, HASTE}, -- Reckless Citrine (Skyguard Bash'ir Landing Event)

-- Instance Drops
[3075] = {30587, REDYELLOW , 5, STRENGTH, 4, DODGE}, -- Champion's Fire Opal
[3070] = {30582, REDYELLOW , 5, AGILITY, 4, CRIT}, -- Deadly Fire Opal
[3072] = {30584, REDYELLOW , 5, STRENGTH, 4, CRIT}, -- Inscribed Fire Opal
[3079] = {30591, REDYELLOW , 5, AGILITY, 4, RESILIENCE}, -- Lucent Fire Opal
[3073] = {30585, REDYELLOW , 4, AGILITY, 5, DODGE}, -- Polished Fire Opal
[3081] = {30593, REDYELLOW , 5, INTELLECT, 4, CRIT}, -- Potent Fire Opal -- multiID
[3076] = {30588, REDYELLOW , 5, INTELLECT, 4, CRIT}, -- Potent Fire Opal -- multiID
[3050] = {30551, REDYELLOW , 5, INTELLECT, 4, HASTE}, -- Reckless Fire Opal -- multiID
[3046] = {30547, REDYELLOW , 5, INTELLECT, 4, HASTE}, -- Reckless Fire Opal -- multiID
[3087] = {30604, REDYELLOW , 5, STRENGTH, 4, RESILIENCE}, -- Resplendent Fire Opal
[3090] = {30607, REDYELLOW , 5, PARRY, 4, RESILIENCE}, -- Splendid Fire Opal
[3056] = {30558, REDYELLOW , 5, PARRY, 4, DODGE}, -- Stalwart Fire Opal -- multiID
[3053] = {30554, REDYELLOW , 5, PARRY, 4, DODGE}, -- Stalwart Fire Opal -- multiID
[3069] = {30581, REDYELLOW , 5, INTELLECT, 4, RESILIENCE}, -- Willful Fire Opal
-- -------------------------------------------------------------------------- --
-- REDBLUE (PURPLE)                                                           --
-- -------------------------------------------------------------------------- --
[2755] = {23100, REDBLUE   , 3, HIT, 3, AGILITY}, -- Glinting Shadow Draenite
[2707] = {23106, REDBLUE   , 3, INTELLECT, 3, SPIRIT}, -- Purified Shadow Draenite -- multiID
[2709] = {23109, REDBLUE   , 3, INTELLECT, 3, SPIRIT}, -- Purified Shadow Draenite -- multiID
[2710] = {23110, REDBLUE   , 3, AGILITY, 4, STAMINA}, -- Shifting Shadow Draenite -- multiID
[3106] = {31862, REDBLUE   , 3, AGILITY, 4, STAMINA}, -- Shifting Shadow Draenite -- multiID
[3108] = {31864, REDBLUE   , 3, AGILITY, 4, STAMINA}, -- Shifting Shadow Draenite -- multiID
[2711] = {23111, REDBLUE   , 3, STRENGTH, 4, STAMINA}, -- Sovereign Shadow Draenite
[2708] = {23108, REDBLUE   , 3, INTELLECT, 4, STAMINA}, -- Timeless Shadow Draenite
[3110] = {31866, REDBLUE   , 3, INTELLECT, 3, HIT}, -- Veiled Shadow Draenite

[2756] = {24061, REDBLUE   , 4, HIT, 4, AGILITY}, -- Glinting Nightseye -- multiID
[3109] = {31865, REDBLUE   , 4, HIT, 4, AGILITY}, -- Glinting Nightseye -- multiID
[2741] = {24057, REDBLUE   , 4, INTELLECT, 4, SPIRIT}, -- Purified Nightseye -- multiID
[2744] = {24065, REDBLUE   , 4, INTELLECT, 4, SPIRIT}, -- Purified Nightseye -- multiID
[2739] = {24055, REDBLUE   , 4, AGILITY, 6, STAMINA}, -- Shifting Nightseye -- multiID
[3107] = {31863, REDBLUE   , 4, AGILITY, 6, STAMINA}, -- Shifting Nightseye -- multiID
[2738] = {24054, REDBLUE   , 4, STRENGTH, 6, STAMINA}, -- Sovereign Nightseye
[2740] = {24056, REDBLUE   , 5, INTELLECT, 6, STAMINA}, -- Timeless Nightseye
[3111] = {31867, REDBLUE   , 4, INTELLECT, 4, HIT}, -- Veiled Nightseye

[3136] = {32214, REDBLUE   , 5, HIT, 5, AGILITY}, -- Glinting Shadowsong Amethyst -- multiID
[3142] = {32220, REDBLUE   , 5, HIT, 5, AGILITY}, -- Glinting Shadowsong Amethyst -- multiID
[3138] = {32216, REDBLUE   , 5, INTELLECT, 5, SPIRIT}, -- Purified Shadowsong Amethyst -- multiID
[3147] = {32225, REDBLUE   , 5, INTELLECT, 5, SPIRIT}, -- Purified Shadowsong Amethyst -- multiID
[3318] = {37503, REDBLUE   , 5, INTELLECT, 5, SPIRIT}, -- Purified Shadowsong Amethyst -- multiID
[3134] = {32212, REDBLUE   , 5, AGILITY, 7, STAMINA}, -- Shifting Shadowsong Amethyst -- multiID
[3135] = {32213, REDBLUE   , 5, AGILITY, 7, STAMINA}, -- Shifting Shadowsong Amethyst -- multiID
[3133] = {32211, REDBLUE   , 5, STRENGTH, 7, STAMINA}, -- Sovereign Shadowsong Amethyst
[3137] = {32215, REDBLUE   , 5, INTELLECT, 7, STAMINA}, -- Timeless Shadowsong Amethyst
[3143] = {32221, REDBLUE   , 5, INTELLECT, 5, HIT}, -- Veiled Shadowsong Amethyst

[3201] = {32833, REDBLUE   , 3, INTELLECT, 3, SPIRIT}, -- Purified Jaggal Pearl
[3202] = {32836, REDBLUE   , 4, INTELLECT, 4, SPIRIT}, -- Purified Shadow Pearl

-- Vendor
[3157] = {32635, REDBLUE   , 4, INTELLECT, 6, STAMINA}, -- Timeless Amethyst (Skyguard Bash'ir Landing Event)
[3156] = {32634, REDBLUE   , 5, AGILITY, 6, STAMINA}, -- Shifting Amethyst (Skyguard Bash'ir Landing Event)
[3158] = {32636, REDBLUE   , 5, INTELLECT, 4, SPIRIT}, -- Purified Amethyst (Skyguard Bash'ir Landing Event)

-- Quest Rewards
[3101] = {31118, REDBLUE   , 5, STRENGTH, 6, STAMINA}, -- Sovereign Amethyst (Quest: 'Nightbane' / Karazhan)
[3099] = {31116, REDBLUE   , 5, INTELLECT, 6, STAMINA}, -- Timeless Amethyst (Quest: 'Nightbane' / Karazhan)
[3100] = {31117, REDBLUE   , 5, INTELLECT, 6, STAMINA}, -- Tireless Soothing Amethyst (Quest: 'Nightbane' / Karazhan)

-- Instance Drops
[3063] = {30566, REDBLUE   , 5, PARRY, 6, STAMINA}, -- Defender's Tanzanite
[3057] = {30559, REDBLUE   , 5, STRENGTH, 4, HIT}, -- Etched Tanzanite
[3055] = {30556, REDBLUE   , 5, AGILITY, 4, HIT}, -- Glinting Tanzanite -- multiID
[3052] = {30553, REDBLUE   , 5, AGILITY, 4, HIT}, -- Glinting Tanzanite -- multiID
[3066] = {30573, REDBLUE   , 5, INTELLECT, 5, PENETRATION}, -- Mysterious Tanzanite
[3074] = {30586, REDBLUE   , 5, INTELLECT, 4, SPIRIT}, -- Purified Tanzanite -- multiID
[3077] = {30589, REDBLUE   , 5, INTELLECT, 4, SPIRIT}, -- Purified Tanzanite -- multiID
[3083] = {30600, REDBLUE   , 5, INTELLECT, 4, SPIRIT}, -- Purified Tanzanite -- multiID
[3086] = {30603, REDBLUE   , 5, INTELLECT, 4, SPIRIT}, -- Purified Tanzanite -- multiID
[3064] = {30572, REDBLUE   , 5, INTELLECT, 5, SPIRIT}, -- Purified Tanzanite -- multiID
[3067] = {30574, REDBLUE   , 5, AGILITY, 6, STAMINA}, -- Shifting Tanzanite -- multiID
[3048] = {30549, REDBLUE   , 5, AGILITY, 6, STAMINA}, -- Shifting Tanzanite -- multiID
[3045] = {30546, REDBLUE   , 5, STRENGTH, 6, STAMINA}, -- Sovereign Tanzanite
[3051] = {30552, REDBLUE   , 5, INTELLECT, 6, STAMINA}, -- Timeless Tanzanite -- multiID
[3071] = {30583, REDBLUE   , 5, INTELLECT, 6, STAMINA}, -- Timeless Tanzanite -- multiID
[3054] = {30555, REDBLUE   , 5, INTELLECT, 6, STAMINA}, -- Timeless Tanzanite -- multiID
[3061] = {30564, REDBLUE   , 5, INTELLECT, 4, HIT}, -- Veiled Tanzanite
-- -------------------------------------------------------------------------- --
-- PRISMATIC                                                                  --
-- -------------------------------------------------------------------------- --
[2947] = {22460, PRISMATIC , 3, HOLY_RES, 3, FIRE_RES, 3, NATURE_RES, 3, FROST_RES, 3, SHADOW_RES, 3, ARCANE_RES}, -- Prismatic Sphere
[2948] = {22459, PRISMATIC , 4, HOLY_RES, 4, FIRE_RES, 4, NATURE_RES, 4, FROST_RES, 4, SHADOW_RES, 4, ARCANE_RES}, -- Void Sphere
-- -------------------------------------------------------------------------- --
-- META                                                                       --
-- -------------------------------------------------------------------------- --
[2832] = {25897, META      , "R>B"      , 12, INTELLECT, -32842, EFFECT}, -- Bracing Earthstorm Diamond   ---REQ: RED>BLUE
-- TODO [2834] = {25899}, -- Brutal Earthstorm Diamond   ---REQ: 2 RED, 2 YELLOW, 2 BLUE
[3274] = {35501, META      , "2B:1Y"    , 12, DODGE, -55283, EFFECT}, -- Eternal Earthstorm Diamond   ---REQ: 2 BLUE, 1 YELLOW
[2835] = {25901, META      , "2R:2Y:2B" , 12, INTELLECT, -27521, EFFECT}, -- Insightful Earthstorm Diamond   ---REQ: 2 RED, 2 YELLOW, 2 BLUE
[2831] = {25896, META      , "3B"       , 18, STAMINA, -55358, EFFECT}, -- Powerful Earthstorm Diamond   ---REQ: 3 BLUE
[3154] = {32409, META      , "3R"       , 12, AGILITY, -39957, EFFECT}, -- Relentless Earthstorm Diamond   ---REQ: 3 RED
[2833] = {25898, META      , "5B"       , 12, DODGE, -32844, EFFECT}, -- Tenacious Earthstorm Diamond   ---REQ: 5 BLUE

[3261] = {34220, META      , "3R"       , 12, CRIT, -44797, EFFECT}, -- Chaotic Skyfire Diamond   ---REQ: 3 RED
[2827] = {25890, META      , "2R:2Y:2B" , 14, CRIT, -11818, EFFECT}, -- Destructive Skyfire Diamond   ---REQ: 2 RED, 2 YELLOW, 2 BLUE
[3275] = {35503, META      , "3R"       , 12, INTELLECT, -55275, EFFECT}, -- Ember Skyfire Diamond   ---REQ: 3 RED
[2830] = {25895, META      , "R>Y"      , 12, CRIT, -55378, EFFECT}, -- Enigmatic Skyfire Diamond   ---REQ: RED>YELLOW
[2828] = {25893, META      , "B>Y"      , -32837, EFFECT}, -- Mystical Skyfire Diamond   ---REQ: BLUE>YELLOW
[2829] = {25894, META      , "2Y:1R"    , 12, CRIT, -23990, EFFECT}, -- Swift Skyfire Diamond   ---REQ: 2 YELLOW, 1 RED
[3155] = {32410, META      , "2R:2Y:2B" , -39958, EFFECT}, -- Thundering Skyfire Diamond   ---REQ: 2 RED, 2 YELLOW, 2 BLUE

-- Vendor
[2970] = {28557, META      , "2Y:1R"    , 10, INTELLECT, -23990, EFFECT}, -- Quickened Starfire Diamond (Terokkar Forest)   ---REQ: 2 YELLOW, 1 RED
[2969] = {28556, META      , "2Y:1R"    , 10, CRIT, -23990, EFFECT}, -- Swift Windfire Diamond (Terokkar Forest)   ---REQ: 2 YELLOW, 1 RED
[3163] = {32641, META      , "3Y"       , 12, INTELLECT, -40706, EFFECT}, -- Imbued Unstable Diamond (Skyguard Bash'ir Landing Event)   ---REQ: 3 YELLOW
[3162] = {32640, META      , "B>Y"      , 12, CRIT, -40691, EFFECT}, -- Tense Unstable Diamond (Skyguard Bash'ir Landing Event)   ---REQ: BLUE>YELLOW
}


function CharScanner_GearStats_Gem(id)
	--    1       2       3     4      5     6      7     8      9     10     11    12     13    14     15
	--    1       2       4     5      6     7      8     9      10    11     12    13     14    15     3       (META)
	local linkid, socket, val1, stat1, val2, stat2, val3, stat3, val4, stat4, val5, stat5, val6, stat6, metareq
	if gemIDs[id] then
		linkid = gemIDs[id][1]
		socket = gemIDs[id][2]
		
		if socket == META then

			metareq = gemIDs[id][3]
			if gemIDs[id][4] then
				val1  = gemIDs[id][4]
				stat1 = gemIDs[id][5]
				if gemIDs[id][6] then
					val2  = gemIDs[id][6]
					stat2 = gemIDs[id][7]
					if gemIDs[id][8] then
						val3  = gemIDs[id][8]
						stat3 = gemIDs[id][9]
						if gemIDs[id][10] then
							val4  = gemIDs[id][10]
							stat4 = gemIDs[id][11]
							if gemIDs[id][12] then
								val5  = gemIDs[id][12]
								stat5 = gemIDs[id][13]
								if gemIDs[id][14] then
									val6  = gemIDs[id][14]
									stat6 = gemIDs[id][15]
								end
							end
						end
					end
				end
			end

		else
		
			if gemIDs[id][3] then
				val1  = gemIDs[id][3]
				stat1 = gemIDs[id][4]
				if gemIDs[id][5] then
					val2  = gemIDs[id][5]
					stat2 = gemIDs[id][6]
					if gemIDs[id][7] then
						val3  = gemIDs[id][7]
						stat3 = gemIDs[id][8]
						if gemIDs[id][9] then
							val4  = gemIDs[id][9]
							stat4 = gemIDs[id][10]
							if gemIDs[id][11] then
								val5  = gemIDs[id][11]
								stat5 = gemIDs[id][12]
								if gemIDs[id][13] then
									val6  = gemIDs[id][13]
									stat6 = gemIDs[id][14]
								end
							end
						end
					end
				end
			end

		end

	end
	return linkid, socket, val1, stat1, val2, stat2, val3, stat3, val4, stat4, val5, stat5, val6, stat6, metareq
end